#
# PySNMP MIB module SMON-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SMON-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:28:37 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( OwnerString, rmon, ) = mibBuilder.importSymbols("RMON-MIB", "OwnerString", "rmon")
( rmonConformance, LastCreateTime, DataSource, probeConfig, ) = mibBuilder.importSymbols("RMON2-MIB", "rmonConformance", "LastCreateTime", "DataSource", "probeConfig")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( ModuleIdentity, iso, TimeTicks, Gauge32, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Integer32, Counter32, Unsigned32, Counter64, ObjectIdentity, IpAddress, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "iso", "TimeTicks", "Gauge32", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Integer32", "Counter32", "Unsigned32", "Counter64", "ObjectIdentity", "IpAddress", "NotificationType")
( RowStatus, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "DisplayString", "TextualConvention")
switchRMON = ModuleIdentity((1, 3, 6, 1, 2, 1, 16, 22))
if mibBuilder.loadTexts: switchRMON.setLastUpdated('9812160000Z')
if mibBuilder.loadTexts: switchRMON.setOrganization('IETF RMON MIB Working Group')
if mibBuilder.loadTexts: switchRMON.setContactInfo('IETF RMONMIB WG Mailing list: rmonmib@cisco.com\n\n                Rich Waterman\n                Allot Networks Inc.\n                Tel:  +1-408-559-0253\n                Email: rich@allot.com\n\n                Bill Lahaye\n                Xylan Corp.\n                Tel: +1-800-995-2612\n                Email:  lahaye@ctron.com\n\n                Dan Romascanu\n                Lucent Technologies\n                Tel:  +972-3-645-8414\n                Email: dromasca@lucent.com\n\n                Steven Waldbusser\n                International Network Services\n                Tel: +1-415-254-4251\n                Email: waldbusser@ins.com')
if mibBuilder.loadTexts: switchRMON.setDescription('The MIB module for managing remote monitoring device\n                 implementations for Switched Networks')
smonMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 22, 1))
dataSourceCaps = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 22, 1, 1))
smonStats = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 22, 1, 2))
portCopyConfig = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 22, 1, 3))
smonRegistrationPoints = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 22, 1, 4))
class SmonDataSource(ObjectIdentifier, TextualConvention):
    pass

smonCapabilities = MibScalar((1, 3, 6, 1, 2, 1, 16, 19, 15), Bits().clone(namedValues=NamedValues(("smonVlanStats", 0), ("smonPrioStats", 1), ("dataSource", 2), ("smonUnusedBit", 3), ("portCopy", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: smonCapabilities.setDescription('An indication of the SMON MIB groups supported\n         by this agent.')
dataSourceCapsTable = MibTable((1, 3, 6, 1, 2, 1, 16, 22, 1, 1, 1), )
if mibBuilder.loadTexts: dataSourceCapsTable.setDescription("This table describes RMON data sources and port copy\n        capabilities. An NMS MAY use this table to discover the\n        identity and attributes of the data sources on a given agent\n        implementation. Similar to the probeCapabilities object,\n        actual row-creation operations will succeed or fail based on\n        the resources available and parameter values used in each\n        row-creation operation.\n\n        Upon restart of the RMON agent, the dataSourceTable, ifTable,\n        and perhaps entPhysicalTable are initialized for the available\n        dataSources.\n\n        For each dataSourceCapsEntry representing a VLAN or\n        entPhysicalEntry the agent MUST create an associated ifEntry\n        with a ifType value of 'propVirtual(53)'. This ifEntry will be\n        used as the actual value in RMON control table dataSource\n        objects. The assigned ifIndex value is copied into the\n        associated dataSourceCapsIfIndex object.\n        It is understood that dataSources representing VLANs may not\n        always be instantiated immediately upon restart, but rather as\n        VLAN usage is detected by the agent. The agent SHOULD attempt\n        to create dataSource and interface entries for all dataSources\n        as soon as possible.")
dataSourceCapsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 22, 1, 1, 1, 1), ).setIndexNames((1, "SMON-MIB", "dataSourceCapsObject"))
if mibBuilder.loadTexts: dataSourceCapsEntry.setDescription('Entries per data source containing descriptions of data\n         source and port copy capabilities. This table is populated by\n         the SMON agent with one entry for each supported data\n         source.')
dataSourceCapsObject = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 1, 1, 1, 1), SmonDataSource())
if mibBuilder.loadTexts: dataSourceCapsObject.setDescription('Defines an object that can be a SMON data source or a\n          source or a destination for a port copy operation.')
dataSourceRmonCaps = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 1, 1, 1, 2), Bits().clone(namedValues=NamedValues(("countErrFrames", 0), ("countAllGoodFrames", 1), ("countAnyRmonTables", 2), ("babyGiantsCountAsGood", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dataSourceRmonCaps.setDescription(" General attributes of the specified dataSource. Note that\n        these are static attributes, which SHOULD NOT be adjusted\n        because of current resources or configuration.\n\n      - countErrFrames(0)\n          The agent sets this bit for the dataSource if errored frames\n          received on this dataSource can actually be monitored by the\n          agent The agent clears this bit if any errored frames are\n          not visible to the RMON data collector.\n\n      - countAllGoodFrames(1)\n          The agent sets this bit for the dataSource if all good\n          frames received on this dataSource can actually be monitored\n          by the agent. The agent clears this bit if any good frames\n          are not visible for RMON collection, e.g., the dataSource is\n          a non-promiscuous interface or an internal switch interface\n          which may not receive frames which were switched in hardware\n          or dropped by the bridge forwarding function.\n\n      - countAnyRmonTables(2)\n          The agent sets this bit if this dataSource can actually be\n          used in any of the implemented RMON tables, resources\n          notwithstanding. The agent clears this bit if this\n          dataSourceCapsEntry is present simply to identify a\n          dataSource that may only be used as portCopySource and/or a\n          portCopyDest, but not the source of an actual RMON data\n          collection.\n\n      - babyGiantsCountAsGood(3)\n          The agent sets this bit if it can distinguish, for counting\n          purposes, between true giant frames and frames that exceed\n          Ethernet maximum frame size 1518 due to VLAN tagging ('baby\n          giants'). Specifically, this BIT means that frames up to\n          1522 octets are counted as good.\n\n          Agents not capable of detecting 'baby giants' will clear\n          this bit and will view all frames less than or equal to 1518\n          octets as 'good frames' and all frames larger than 1518\n          octets as 'bad frames' for the purpose of counting in the\n          smonVlanIdStats and smonPrioStats tables.\n\n          Agents capable of detecting 'baby giants' SHALL consider\n          them as 'good frames' for the purpose of counting in the\n          smonVlanIdStats and smonPrioStats tables.")
dataSourceCopyCaps = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 1, 1, 1, 3), Bits().clone(namedValues=NamedValues(("copySourcePort", 0), ("copyDestPort", 1), ("copySrcTxTraffic", 2), ("copySrcRxTraffic", 3), ("countDestDropEvents", 4), ("copyErrFrames", 5), ("copyUnalteredFrames", 6), ("copyAllGoodFrames", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dataSourceCopyCaps.setDescription('PortCopy function capabilities of the specified dataSource.\n    Note that these are static capabilities, which SHOULD NOT be\n    adjusted because of current resources or configuration.\n\n      - copySourcePort(0)\n          The agent sets this bit if this dataSource is capable of\n          acting as a source of a portCopy operation. The agent clears\n          this bit otherwise.\n\n      - copyDestPort(1)\n          The agent sets this bit if this dataSource is capable of\n          acting as a destination of a portCopy operation. The agent\n          clears this bit otherwise.\n\n     - copySrcTxTraffic(2)\n          If the copySourcePort bit is set:\n                The agent sets this bit if this dataSource is capable of\n              copying frames transmitted out this portCopy source. The\n              agent clears this bit otherwise. This function is needed\n              to support full-duplex ports.\n           Else:\n               this bit SHOULD be cleared.\n\n      - copySrcRxTraffic(3)\n          If the copySourcePort bit is set:\n            The agent sets this bit if this dataSource is capable of\n            copying frames received on this portCopy source. The agent\n            clears this bit otherwise. This function is needed to\n            support full-duplex ports.\n          Else:\n            this bit SHOULD be cleared.\n\n      - countDestDropEvents(4)\n          If the copyDestPort bit is set:\n              The agent sets this bit if it is capable of incrementing\n              portCopyDestDropEvents, when this dataSource is the\n              target of a portCopy operation and a frame destined to\n              this dataSource is dropped (for RMON counting purposes).\n          Else:\n              this BIT SHOULD be cleared.\n\n      - copyErrFrames(5)\n          If the copySourcePort bit is set:\n              The agent sets this bit if it is capable of copying all\n              errored frames from this portCopy source-port, for\n              errored frames received on this dataSource.\n          Else:\n              this BIT SHOULD be cleared.\n\n      - copyUnalteredFrames(6)\n          If the copySourcePort bit is set:\n              The agent sets the copyUnalteredFrames bit If it is\n              capable of copying all frames from this portCopy\n              source-port without alteration in any way;\n          Else:\n              this bit SHOULD be cleared.\n\n      - copyAllGoodFrames(7)\n          If the copySourcePort bit is set:\n              The agent sets this bit for the dataSource if all good\n              frames received on this dataSource are normally capable\n              of being copied by the agent. The agent clears this bit\n              if any good frames are not visible for the RMON portCopy\n              operation, e.g., the dataSource is a non-promiscuous\n              interface or an internal switch interface which may not\n              receive frames which were switched in hardware or\n              dropped by the bridge forwarding function.\n           Else:\n              this bit SHOULD be cleared.')
dataSourceCapsIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 1, 1, 1, 4), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dataSourceCapsIfIndex.setDescription("This object contains the ifIndex value of the ifEntry\n         associated with this smonDataSource. The agent MUST create\n         'propVirtual' ifEntries for each dataSourceCapsEntry of type\n         VLAN or entPhysicalEntry.")
smonVlanStatsControlTable = MibTable((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1), )
if mibBuilder.loadTexts: smonVlanStatsControlTable.setDescription('Controls the setup of VLAN statistics tables.\n\n         The statistics collected represent a distribution based on\n         the IEEE 802.1Q VLAN-ID (VID), for each good frame attributed\n         to the data source for the collection.')
smonVlanStatsControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1, 1), ).setIndexNames((0, "SMON-MIB", "smonVlanStatsControlIndex"))
if mibBuilder.loadTexts: smonVlanStatsControlEntry.setDescription('A conceptual row in the smonVlanStatsControlTable.')
smonVlanStatsControlIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: smonVlanStatsControlIndex.setDescription('A unique arbitrary index for this smonVlanStatsControlEntry.')
smonVlanStatsControlDataSource = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1, 1, 2), DataSource()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: smonVlanStatsControlDataSource.setDescription('The source of data for this set of VLAN statistics.\n\n        This object MAY NOT be modified if the associated\n        smonVlanStatsControlStatus object is equal to active(1).')
smonVlanStatsControlCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1, 1, 3), LastCreateTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanStatsControlCreateTime.setDescription('The value of sysUpTime when this control entry was last\n        activated. This object allows to a management station to\n        detect deletion and recreation cycles between polls.')
smonVlanStatsControlOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1, 1, 4), OwnerString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: smonVlanStatsControlOwner.setDescription('Administratively assigned named of the owner of this entry.\n        It usually defines the entity that created this entry and is\n        therefore using the resources assigned to it, though there is\n        no enforcement mechanism, nor assurance that rows created are\n        ever used.')
smonVlanStatsControlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 1, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: smonVlanStatsControlStatus.setDescription('The status of this row.\n\n        An entry MAY NOT exist in the active state unless all\n        objects in the entry have an appropriate value.\n\n        If this object is not equal to active(1), all associated\n        entries in the smonVlanIdStatsTable SHALL be deleted.')
smonVlanIdStatsTable = MibTable((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2), )
if mibBuilder.loadTexts: smonVlanIdStatsTable.setDescription('Contains the VLAN statistics data.\n         The statistics collected represent a distribution based\n         on the IEEE 802.1Q VLAN-ID (VID), for each good frame\n         attributed to the data source for the collection.\n\n         This function applies the same rules for attributing frames\n         to VLAN-based collections. RMON VLAN statistics are collected\n         after the Ingress Rules defined in section 3.13 of the VLAN\n         Specification [20] are applied.\n\n         It is possible that entries in this table will be\n         garbage-collected, based on agent resources, and VLAN\n         configuration. Agents are encouraged to support all 4094\n         index values and not garbage collect this table.')
smonVlanIdStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1), ).setIndexNames((0, "SMON-MIB", "smonVlanStatsControlIndex"), (0, "SMON-MIB", "smonVlanIdStatsId"))
if mibBuilder.loadTexts: smonVlanIdStatsEntry.setDescription('A conceptual row in smonVlanIdStatsTable.')
smonVlanIdStatsId = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,4094)))
if mibBuilder.loadTexts: smonVlanIdStatsId.setDescription('The unique identifier of the VLAN monitored for\n         this specific statistics collection.\n\n        Tagged packets match the VID for the range between 1 and 4094.\n        An external RMON probe MAY detect VID=0 on an Inter Switch\n        Link, in which case the packet belongs to a VLAN determined by\n        the PVID of the ingress port. The VLAN to which such a packet\n        belongs can be determined only by a RMON probe internal to the\n        switch.')
smonVlanIdStatsTotalPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 2), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsTotalPkts.setDescription('The total number of packets counted on this VLAN.')
smonVlanIdStatsTotalOverflowPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 3), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsTotalOverflowPkts.setDescription('The number of times the associated smonVlanIdStatsTotalPkts\n         counter has overflowed.')
smonVlanIdStatsTotalHCPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 4), Counter64()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsTotalHCPkts.setDescription('The total number of packets counted on this VLAN.')
smonVlanIdStatsTotalOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 5), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsTotalOctets.setDescription('The total number of octets counted on this VLAN.')
smonVlanIdStatsTotalOverflowOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 6), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsTotalOverflowOctets.setDescription('The number of times the associated smonVlanIdStatsTotalOctets\n         counter has overflowed.')
smonVlanIdStatsTotalHCOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 7), Counter64()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsTotalHCOctets.setDescription('The total number of octets counted on this VLAN.')
smonVlanIdStatsNUcastPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsNUcastPkts.setDescription('The total number of non-unicast packets counted on this\n         VLAN.')
smonVlanIdStatsNUcastOverflowPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsNUcastOverflowPkts.setDescription('The number of times the associated smonVlanIdStatsNUcastPkts\n         counter has overflowed.')
smonVlanIdStatsNUcastHCPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 10), Counter64()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsNUcastHCPkts.setDescription('The total number of non-unicast packets counted on\n         this VLAN.')
smonVlanIdStatsNUcastOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 11), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsNUcastOctets.setDescription('The total number of non-unicast octets counted on\n         this VLAN.')
smonVlanIdStatsNUcastOverflowOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 12), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsNUcastOverflowOctets.setDescription('The number of times the associated\n         smonVlanIdStatsNUcastOctets counter has overflowed.')
smonVlanIdStatsNUcastHCOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 13), Counter64()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsNUcastHCOctets.setDescription('The total number of Non-unicast octets counted on\n         this VLAN.')
smonVlanIdStatsCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 2, 1, 14), LastCreateTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: smonVlanIdStatsCreateTime.setDescription('The value of sysUpTime when this entry was last\n        activated. This object allows to a management station to\n        detect deletion and recreation cycles between polls.')
smonPrioStatsControlTable = MibTable((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3), )
if mibBuilder.loadTexts: smonPrioStatsControlTable.setDescription('Controls the setup of priority statistics tables.\n\n         The smonPrioStatsControlTable allows configuration of\n         collections based on the value of the 3-bit user priority\n         field encoded in the Tag Control Information (TCI) field\n         according to [19],[20].\n\n         Note that this table merely reports priority as encoded in\n         the VLAN headers, not the priority (if any) given to the\n         frame for the actual switching purposes.')
smonPrioStatsControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3, 1), ).setIndexNames((0, "SMON-MIB", "smonPrioStatsControlIndex"))
if mibBuilder.loadTexts: smonPrioStatsControlEntry.setDescription('A conceptual row in the smonPrioStatsControlTable.')
smonPrioStatsControlIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: smonPrioStatsControlIndex.setDescription('A unique arbitrary index for this smonPrioStatsControlEntry.')
smonPrioStatsControlDataSource = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3, 1, 2), DataSource()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: smonPrioStatsControlDataSource.setDescription('The source of data for this set of VLAN statistics.\n\n        This object MAY NOT be modified if the associated\n        smonPrioStatsControlStatus object is equal to active(1).')
smonPrioStatsControlCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3, 1, 3), LastCreateTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsControlCreateTime.setDescription('The value of sysUpTime when this entry was created.\n        This object allows to a management station to\n        detect deletion and recreation cycles between polls.')
smonPrioStatsControlOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3, 1, 4), OwnerString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: smonPrioStatsControlOwner.setDescription('Administratively assigned named of the owner of this entry.\n        It usually defines the entity that created this entry and is\n        therefore using the resources assigned to it, though there is\n        no enforcement mechanism, nor assurance that rows created are\n        ever used.')
smonPrioStatsControlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 3, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: smonPrioStatsControlStatus.setDescription('The status of this row.\n        An entry MAY NOT exist in the active state unless all\n        objects in the entry have an appropriate value.\n\n        If this object is not equal to active(1), all associated\n        entries in the smonPrioStatsTable SHALL be deleted.')
smonPrioStatsTable = MibTable((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4), )
if mibBuilder.loadTexts: smonPrioStatsTable.setDescription('Contains the priority statistics. The collections are based\n         on the value of the 3-bit user priority field encoded in the\n         Tag Control Information (TCI) field according to [19], [20].\n         Note that this table merely reports priority as encoded in\n         the VLAN headers, not the priority (if any) given to the\n         frame for the actual switching purposes.\n\n         No garbage collection is designed for this table, as there\n         always are at most eight rows per statistical set, and the\n         low memory requirements do not justify the implementation of\n         such a mechanism.')
smonPrioStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1), ).setIndexNames((0, "SMON-MIB", "smonPrioStatsControlIndex"), (0, "SMON-MIB", "smonPrioStatsId"))
if mibBuilder.loadTexts: smonPrioStatsEntry.setDescription('A conceptual row in smonPrioStatsTable.')
smonPrioStatsId = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7)))
if mibBuilder.loadTexts: smonPrioStatsId.setDescription('The unique identifier of the priority level monitored for\n         this specific statistics collection.')
smonPrioStatsPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 2), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsPkts.setDescription('The total number of packets counted on\n         this priority level.')
smonPrioStatsOverflowPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 3), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsOverflowPkts.setDescription('The number of times the associated smonPrioStatsPkts\n         counter has overflowed.')
smonPrioStatsHCPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 4), Counter64()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsHCPkts.setDescription('The total number of packets counted on\n         this priority level.')
smonPrioStatsOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 5), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsOctets.setDescription('The total number of octets counted on\n         this priority level.')
smonPrioStatsOverflowOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 6), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsOverflowOctets.setDescription('The number of times the associated smonPrioStatsOctets\n         counter has overflowed.')
smonPrioStatsHCOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 2, 4, 1, 7), Counter64()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: smonPrioStatsHCOctets.setDescription('The total number of octets counted on\n         this priority level.')
portCopyTable = MibTable((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1), )
if mibBuilder.loadTexts: portCopyTable.setDescription(" Port Copy provides the ability to copy all frames from a\n         specified source to specified destination within a switch.\n         Source and destinations MUST be ifEntries, as defined by [22].\n         One to one, one to many, many to one and many to many source to\n         destination relationships may be configured.\n\n         Applicable counters on the destination will increment for all\n         packets transiting the port, be it by normal bridging/switching\n         or due to packet copy.\n         Note that this table manages no RMON data collection by itself,\n         and an agent may possibly implement no RMON objects except\n         objects related to the port copy operation defined by the\n         portCopyCompliance conformance macro. That allows for a switch\n         with no other embedded RMON capability to perform port copy\n         operations to a destination port at which a different external\n         RMON probe is connected.\n\n         One to one, many to one and one to many source to destination\n         relationships may be configured.\n\n         Each row that exists in this table defines such a\n         relationship. By disabling a row in this table the port copy\n         relationship no longer exists.\n\n         The number of entries and the types of port copies (1-1,\n         many-1, 1-many) are implementation specific and could\n         possibly be dynamic due to changing resource availability.\n\n         In order to configure a source to destination portCopy\n         relationship, both source and destination interfaces MUST be\n         present as an ifEntry in the ifTable and their respective\n         ifAdminStatus and ifOperStatus values MUST be equal to\n         'up(1)'. If the value of any of those two objects changes\n         after the portCopyEntry is activated, portCopyStatus will\n         transition to 'notReady(3)'.\n\n         The capability of an interface to be source or destination of\n         a port copy operation is described by the 'copySourcePort(0)'\n         and 'copyDestPort(1)' bits in dataSourceCopyCaps. Those bits\n         SHOULD be appropriately set by the agent, in order to allow\n         for a portCopyEntry to be created.\n\n         Applicable counters on the destination will increment for all\n         packets transmitted, be it by normal bridging/switching or\n         due to packet copy.")
portCopyEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1, 1), ).setIndexNames((0, "SMON-MIB", "portCopySource"), (0, "SMON-MIB", "portCopyDest"))
if mibBuilder.loadTexts: portCopyEntry.setDescription('Describes a particular port copy entry.')
portCopySource = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: portCopySource.setDescription('The ifIndex of the source which will have all packets\n         redirected to the destination as defined by portCopyDest.')
portCopyDest = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1, 1, 2), InterfaceIndex())
if mibBuilder.loadTexts: portCopyDest.setDescription('Defines the ifIndex destination for the copy operation.')
portCopyDestDropEvents = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1, 1, 3), Counter32()).setUnits('events').setMaxAccess("readonly")
if mibBuilder.loadTexts: portCopyDestDropEvents.setDescription('The total number of events in which port copy packets were\n         dropped by the switch at the destination port due to lack of\n         resources.\n\n         Note that this number is not necessarily the number of\n         packets dropped; it is just the number of times this\n         condition has been detected.\n\n         A single dropped event counter is maintained for each\n         portCopyDest. Thus all instances associated with a given\n         portCopyDest will have the same portCopyDestDropEvents\n         value.')
portCopyDirection = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("copyRxOnly", 1), ("copyTxOnly", 2), ("copyBoth", 3),)).clone('copyBoth')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: portCopyDirection.setDescription("This object affects the way traffic is copied from a switch\n          source port, for the indicated port copy operation.\n\n\n         If this object has the value 'copyRxOnly(1)', then only\n         traffic received on the indicated source port will be copied\n         to the indicated destination port.\n\n         If this object has the value 'copyTxOnly(2)', then only\n         traffic transmitted out the indicated source port will be\n         copied to the indicated destination port.\n\n         If this object has the value 'copyBoth(3)', then all traffic\n         received or transmitted on the indicated source port will be\n         copied to the indicated destination port.\n\n         The creation and deletion of instances of this object is\n         controlled by the portCopyRowStatus object. Note that there\n         is no guarantee that changes in the value of this object\n         performed while the associated portCopyRowStatus object is\n         equal to active will not cause traffic discontinuities in the\n         packet stream.")
portCopyStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 22, 1, 3, 1, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: portCopyStatus.setDescription("Defines the status of the port copy entry.\n\n         In order to configure a source to destination portCopy\n         relationship, both source and destination interfaces MUST be\n         present as an ifEntry in the ifTable and their respective\n         ifAdminStatus and ifOperStatus values MUST be equal to\n         'up(1)'. If the value of any of those two objects changes\n         after the portCopyEntry is activated, portCopyStatus will\n         transition to 'notReady(3)'.\n\n         The capability of an interface to be source or destination of\n         a port copy operation is described by the 'copySourcePort(0)'\n         and 'copyDestPort(1)' bits in dataSourceCopyCaps. Those bits\n         SHOULD be appropriately set by the agent, in order to allow\n         for a portCopyEntry to be created.")
smonVlanDataSource = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 22, 1, 4, 1))
smonMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 20, 3))
smonMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 20, 4))
smonMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 20, 3, 1)).setObjects(*(("SMON-MIB", "dataSourceCapsGroup"), ("SMON-MIB", "smonVlanStatsGroup"), ("SMON-MIB", "smonPrioStatsGroup"), ("SMON-MIB", "portCopyConfigGroup"), ("SMON-MIB", "smonInformationGroup"), ("SMON-MIB", "smonHcTo100mbGroup"), ("SMON-MIB", "smonHc100mbPlusGroup"),))
if mibBuilder.loadTexts: smonMIBCompliance.setDescription('Describes the requirements for full conformance with the SMON\n        MIB')
smonMIBVlanStatsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 20, 3, 2)).setObjects(*(("SMON-MIB", "dataSourceCapsGroup"), ("SMON-MIB", "smonVlanStatsGroup"), ("SMON-MIB", "smonInformationGroup"), ("SMON-MIB", "hcVlanTo100mbGroup"), ("SMON-MIB", "hcVlan100mbPlusGroup"),))
if mibBuilder.loadTexts: smonMIBVlanStatsCompliance.setDescription('Describes the requirements for conformance with the SMON MIB\n         with support for VLAN Statistics. Mandatory for a SMON probe\n         in environment where IEEE 802.1Q bridging is implemented.')
smonMIBPrioStatsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 20, 3, 3)).setObjects(*(("SMON-MIB", "dataSourceCapsGroup"), ("SMON-MIB", "smonPrioStatsGroup"), ("SMON-MIB", "smonInformationGroup"), ("SMON-MIB", "hcPrioTo100mbGroup"), ("SMON-MIB", "hcPrio100mbPlusGroup"),))
if mibBuilder.loadTexts: smonMIBPrioStatsCompliance.setDescription('Describes the requirements for conformance with the SMON MIB\n         with support for priority level Statistics. Mandatory for a\n         SMON probe in a environment where IEEE 802.1p\n         priority-switching is implemented.')
portCopyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 20, 3, 4)).setObjects(*(("SMON-MIB", "dataSourceCapsGroup"), ("SMON-MIB", "portCopyConfigGroup"), ("SMON-MIB", "smonInformationGroup"),))
if mibBuilder.loadTexts: portCopyCompliance.setDescription('Describes the requirements for conformance with the port copy\n         functionality defined by the SMON MIB')
dataSourceCapsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 1)).setObjects(*(("SMON-MIB", "dataSourceRmonCaps"), ("SMON-MIB", "dataSourceCopyCaps"), ("SMON-MIB", "dataSourceCapsIfIndex"),))
if mibBuilder.loadTexts: dataSourceCapsGroup.setDescription('Defines the objects that describe the capabilities of RMON\n         data sources.')
smonVlanStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 2)).setObjects(*(("SMON-MIB", "smonVlanStatsControlDataSource"), ("SMON-MIB", "smonVlanStatsControlCreateTime"), ("SMON-MIB", "smonVlanStatsControlOwner"), ("SMON-MIB", "smonVlanStatsControlStatus"), ("SMON-MIB", "smonVlanIdStatsTotalPkts"), ("SMON-MIB", "smonVlanIdStatsTotalOctets"), ("SMON-MIB", "smonVlanIdStatsNUcastPkts"), ("SMON-MIB", "smonVlanIdStatsCreateTime"),))
if mibBuilder.loadTexts: smonVlanStatsGroup.setDescription('Defines the switch monitoring specific statistics - per VLAN\n         Id on interfaces of 10MB or less.')
smonPrioStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 3)).setObjects(*(("SMON-MIB", "smonPrioStatsControlDataSource"), ("SMON-MIB", "smonPrioStatsControlCreateTime"), ("SMON-MIB", "smonPrioStatsControlOwner"), ("SMON-MIB", "smonPrioStatsControlStatus"), ("SMON-MIB", "smonPrioStatsPkts"), ("SMON-MIB", "smonPrioStatsOctets"),))
if mibBuilder.loadTexts: smonPrioStatsGroup.setDescription('Defines the switch monitoring specific statistics - per VLAN\n         Id on interface.')
smonHcTo100mbGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 4)).setObjects(*(("SMON-MIB", "smonVlanIdStatsTotalOverflowOctets"), ("SMON-MIB", "smonVlanIdStatsTotalHCOctets"), ("SMON-MIB", "smonPrioStatsOverflowOctets"), ("SMON-MIB", "smonPrioStatsHCOctets"),))
if mibBuilder.loadTexts: smonHcTo100mbGroup.setDescription('Defines the additional high capacity statistics needed to be\n         kept on interfaces with ifSpeed greater than 10MB/sec and\n         less than or equal to 100MB/sec.')
smonHc100mbPlusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 5)).setObjects(*(("SMON-MIB", "smonVlanIdStatsTotalOverflowPkts"), ("SMON-MIB", "smonVlanIdStatsTotalHCPkts"), ("SMON-MIB", "smonVlanIdStatsTotalOverflowOctets"), ("SMON-MIB", "smonVlanIdStatsTotalHCOctets"), ("SMON-MIB", "smonVlanIdStatsNUcastOverflowPkts"), ("SMON-MIB", "smonVlanIdStatsNUcastHCPkts"), ("SMON-MIB", "smonPrioStatsOverflowPkts"), ("SMON-MIB", "smonPrioStatsHCPkts"), ("SMON-MIB", "smonPrioStatsOverflowOctets"), ("SMON-MIB", "smonPrioStatsHCOctets"),))
if mibBuilder.loadTexts: smonHc100mbPlusGroup.setDescription('Defines the additional high capacity statistics needed to be\n         kept on interfaces with ifSpeed of more than 100MB/sec. These\n         statistics MUST also be kept on smonDataSources of type VLAN\n         or entPhysicalEntry.')
hcVlanTo100mbGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 6)).setObjects(*(("SMON-MIB", "smonVlanIdStatsTotalOverflowOctets"), ("SMON-MIB", "smonVlanIdStatsTotalHCOctets"),))
if mibBuilder.loadTexts: hcVlanTo100mbGroup.setDescription('Defines the additional high capacity VLAN statistics\n         needed to be kept on interfaces with ifSpeed greater than\n         10MB/sec and less than or equal to 100MB/sec.')
hcVlan100mbPlusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 7)).setObjects(*(("SMON-MIB", "smonVlanIdStatsTotalOverflowPkts"), ("SMON-MIB", "smonVlanIdStatsTotalHCPkts"), ("SMON-MIB", "smonVlanIdStatsTotalOverflowOctets"), ("SMON-MIB", "smonVlanIdStatsTotalHCOctets"), ("SMON-MIB", "smonVlanIdStatsNUcastOverflowPkts"), ("SMON-MIB", "smonVlanIdStatsNUcastHCPkts"),))
if mibBuilder.loadTexts: hcVlan100mbPlusGroup.setDescription('Defines the additional high capacity VLAN statistics\n         needed to be kept on interfaces with ifSpeed of more than\n         100MB/sec.  These statistics MUST also be kept on\n         smonDataSources of type VLAN or entPhysicalEntry.')
hcPrioTo100mbGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 8)).setObjects(*(("SMON-MIB", "smonPrioStatsOverflowOctets"), ("SMON-MIB", "smonPrioStatsHCOctets"),))
if mibBuilder.loadTexts: hcPrioTo100mbGroup.setDescription('Defines the additional high capacity VLAN priority\n         statistics needed to be kept on interfaces with\n         ifSpeed of greater than 10MB/sec and less than or equal\n         to 100MB/sec.')
hcPrio100mbPlusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 9)).setObjects(*(("SMON-MIB", "smonPrioStatsOverflowPkts"), ("SMON-MIB", "smonPrioStatsHCPkts"), ("SMON-MIB", "smonPrioStatsOverflowOctets"), ("SMON-MIB", "smonPrioStatsHCOctets"),))
if mibBuilder.loadTexts: hcPrio100mbPlusGroup.setDescription('Defines the additional high capacity VLAN priority\n         statistics needed to be kept on interfaces with\n         ifSpeed of greater than 100MB/sec. These statistics MUST\n         also be kept on smonDataSources of type VLAN or\n         entPhysicalEntry.')
smonVlanStatsExtGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 10)).setObjects(*(("SMON-MIB", "smonVlanIdStatsNUcastOctets"), ("SMON-MIB", "smonVlanIdStatsNUcastOverflowOctets"), ("SMON-MIB", "smonVlanIdStatsNUcastHCOctets"),))
if mibBuilder.loadTexts: smonVlanStatsExtGroup.setDescription('Defines the switch monitoring specific statistics for systems\n         capable of counting non-unicast octets for a given dataSource\n         (as described in the dataSourceRmonCaps object).')
smonInformationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 11)).setObjects(*(("SMON-MIB", "smonCapabilities"),))
if mibBuilder.loadTexts: smonInformationGroup.setDescription('An indication of the SMON capabilities supported by this\n        agent.')
portCopyConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 20, 4, 12)).setObjects(*(("SMON-MIB", "portCopyDestDropEvents"), ("SMON-MIB", "portCopyDirection"), ("SMON-MIB", "portCopyStatus"),))
if mibBuilder.loadTexts: portCopyConfigGroup.setDescription('Defines the control objects for copy port operations.')
mibBuilder.exportSymbols("SMON-MIB", smonVlanIdStatsNUcastOverflowOctets=smonVlanIdStatsNUcastOverflowOctets, smonVlanIdStatsTotalHCPkts=smonVlanIdStatsTotalHCPkts, portCopyDestDropEvents=portCopyDestDropEvents, dataSourceCapsGroup=dataSourceCapsGroup, smonMIBCompliance=smonMIBCompliance, smonPrioStatsControlDataSource=smonPrioStatsControlDataSource, hcVlan100mbPlusGroup=hcVlan100mbPlusGroup, smonVlanIdStatsTotalOverflowOctets=smonVlanIdStatsTotalOverflowOctets, dataSourceCaps=dataSourceCaps, smonMIBVlanStatsCompliance=smonMIBVlanStatsCompliance, smonVlanStatsControlDataSource=smonVlanStatsControlDataSource, smonPrioStatsControlIndex=smonPrioStatsControlIndex, smonVlanStatsControlIndex=smonVlanStatsControlIndex, smonInformationGroup=smonInformationGroup, PYSNMP_MODULE_ID=switchRMON, portCopyEntry=portCopyEntry, smonMIBCompliances=smonMIBCompliances, portCopyDest=portCopyDest, smonMIBObjects=smonMIBObjects, smonVlanStatsControlOwner=smonVlanStatsControlOwner, smonVlanStatsControlStatus=smonVlanStatsControlStatus, smonPrioStatsOverflowPkts=smonPrioStatsOverflowPkts, smonPrioStatsControlTable=smonPrioStatsControlTable, portCopyDirection=portCopyDirection, smonHcTo100mbGroup=smonHcTo100mbGroup, smonPrioStatsControlEntry=smonPrioStatsControlEntry, smonMIBPrioStatsCompliance=smonMIBPrioStatsCompliance, smonVlanIdStatsTotalPkts=smonVlanIdStatsTotalPkts, smonVlanIdStatsId=smonVlanIdStatsId, smonPrioStatsTable=smonPrioStatsTable, portCopyStatus=portCopyStatus, hcPrioTo100mbGroup=hcPrioTo100mbGroup, portCopyConfig=portCopyConfig, dataSourceCopyCaps=dataSourceCopyCaps, smonPrioStatsId=smonPrioStatsId, smonVlanIdStatsTotalHCOctets=smonVlanIdStatsTotalHCOctets, portCopySource=portCopySource, portCopyTable=portCopyTable, dataSourceCapsIfIndex=dataSourceCapsIfIndex, smonVlanStatsControlEntry=smonVlanStatsControlEntry, dataSourceCapsObject=dataSourceCapsObject, smonVlanStatsExtGroup=smonVlanStatsExtGroup, portCopyConfigGroup=portCopyConfigGroup, smonVlanStatsControlCreateTime=smonVlanStatsControlCreateTime, smonVlanIdStatsNUcastOverflowPkts=smonVlanIdStatsNUcastOverflowPkts, smonVlanIdStatsTable=smonVlanIdStatsTable, hcPrio100mbPlusGroup=hcPrio100mbPlusGroup, dataSourceRmonCaps=dataSourceRmonCaps, smonRegistrationPoints=smonRegistrationPoints, smonCapabilities=smonCapabilities, smonMIBGroups=smonMIBGroups, smonVlanIdStatsTotalOverflowPkts=smonVlanIdStatsTotalOverflowPkts, smonHc100mbPlusGroup=smonHc100mbPlusGroup, dataSourceCapsEntry=dataSourceCapsEntry, smonPrioStatsPkts=smonPrioStatsPkts, smonPrioStatsHCPkts=smonPrioStatsHCPkts, smonStats=smonStats, smonVlanDataSource=smonVlanDataSource, smonPrioStatsOctets=smonPrioStatsOctets, smonVlanStatsControlTable=smonVlanStatsControlTable, smonVlanIdStatsTotalOctets=smonVlanIdStatsTotalOctets, SmonDataSource=SmonDataSource, smonPrioStatsEntry=smonPrioStatsEntry, smonVlanIdStatsNUcastOctets=smonVlanIdStatsNUcastOctets, smonVlanIdStatsNUcastHCOctets=smonVlanIdStatsNUcastHCOctets, smonVlanIdStatsCreateTime=smonVlanIdStatsCreateTime, hcVlanTo100mbGroup=hcVlanTo100mbGroup, smonPrioStatsOverflowOctets=smonPrioStatsOverflowOctets, smonPrioStatsHCOctets=smonPrioStatsHCOctets, smonPrioStatsControlOwner=smonPrioStatsControlOwner, dataSourceCapsTable=dataSourceCapsTable, smonPrioStatsControlStatus=smonPrioStatsControlStatus, switchRMON=switchRMON, smonVlanStatsGroup=smonVlanStatsGroup, smonVlanIdStatsNUcastPkts=smonVlanIdStatsNUcastPkts, smonPrioStatsControlCreateTime=smonPrioStatsControlCreateTime, smonPrioStatsGroup=smonPrioStatsGroup, smonVlanIdStatsEntry=smonVlanIdStatsEntry, smonVlanIdStatsNUcastHCPkts=smonVlanIdStatsNUcastHCPkts, portCopyCompliance=portCopyCompliance)



#
# PySNMP MIB module DISMAN-PING-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DISMAN-PING-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:08:09 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Counter64, Unsigned32, Bits, TimeTicks, ModuleIdentity, NotificationType, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, IpAddress, MibIdentifier, iso, Integer32, mib_2, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "Unsigned32", "Bits", "TimeTicks", "ModuleIdentity", "NotificationType", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "IpAddress", "MibIdentifier", "iso", "Integer32", "mib-2", "ObjectIdentity")
( RowStatus, TextualConvention, DateAndTime, TruthValue, DisplayString, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "DateAndTime", "TruthValue", "DisplayString", "StorageType")
pingMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 80)).setRevisions(("2006-06-13 00:00", "2000-09-21 00:00",))
if mibBuilder.loadTexts: pingMIB.setLastUpdated('200606130000Z')
if mibBuilder.loadTexts: pingMIB.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: pingMIB.setContactInfo('Juergen Quittek\n\n           NEC Europe Ltd.\n           Network Laboratories\n           Kurfuersten-Anlage 36\n           69115 Heidelberg\n           Germany\n\n           Phone: +49 6221 4342-115\n           Email: quittek@netlab.nec.de')
if mibBuilder.loadTexts: pingMIB.setDescription('The Ping MIB (DISMAN-PING-MIB) provides the capability of\n           controlling the use of the ping function at a remote\n           host.\n\n           Copyright (C) The Internet Society (2006).  This version of\n           this MIB module is part of RFC 4560; see the RFC itself for\n           full legal notices.')
class OperationResponseStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,))
    namedValues = NamedValues(("responseReceived", 1), ("unknown", 2), ("internalError", 3), ("requestTimedOut", 4), ("unknownDestinationAddress", 5), ("noRouteToTarget", 6), ("interfaceInactiveToTarget", 7), ("arpFailure", 8), ("maxConcurrentLimitReached", 9), ("unableToResolveDnsName", 10), ("invalidHostAddress", 11),)

pingNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 80, 0))
pingObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 80, 1))
pingConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 80, 2))
pingImplementationTypeDomains = MibIdentifier((1, 3, 6, 1, 2, 1, 80, 3))
pingIcmpEcho = ObjectIdentity((1, 3, 6, 1, 2, 1, 80, 3, 1))
if mibBuilder.loadTexts: pingIcmpEcho.setDescription("Indicates that an implementation is using the Internet\n           Control Message Protocol (ICMP) 'ECHO' facility.")
pingUdpEcho = ObjectIdentity((1, 3, 6, 1, 2, 1, 80, 3, 2))
if mibBuilder.loadTexts: pingUdpEcho.setDescription('Indicates that an implementation is using the UDP echo\n           port (7).')
pingSnmpQuery = ObjectIdentity((1, 3, 6, 1, 2, 1, 80, 3, 3))
if mibBuilder.loadTexts: pingSnmpQuery.setDescription('Indicates that an implementation is using an SNMP query\n            to calculate a round trip time.')
pingTcpConnectionAttempt = ObjectIdentity((1, 3, 6, 1, 2, 1, 80, 3, 4))
if mibBuilder.loadTexts: pingTcpConnectionAttempt.setDescription('Indicates that an implementation is attempting to\n           connect to a TCP port in order to calculate a round\n           trip time.')
pingMaxConcurrentRequests = MibScalar((1, 3, 6, 1, 2, 1, 80, 1, 1), Unsigned32().clone(10)).setUnits('requests').setMaxAccess("readwrite")
if mibBuilder.loadTexts: pingMaxConcurrentRequests.setDescription('The maximum number of concurrent active ping requests\n          that are allowed within an agent implementation.  A value\n          of 0 for this object implies that there is no limit for\n          the number of concurrent active requests in effect.\n          The limit applies only to new requests being activated.\n          When a new value is set, the agent will continue processing\n          all the requests already active, even if their number\n          exceeds the limit just imposed.')
pingCtlTable = MibTable((1, 3, 6, 1, 2, 1, 80, 1, 2), )
if mibBuilder.loadTexts: pingCtlTable.setDescription('Defines the ping Control Table for providing, via SNMP,\n           the capability of performing ping operations at\n           a remote host.  The results of these operations are\n           stored in the pingResultsTable and the\n           pingProbeHistoryTable.')
pingCtlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 80, 1, 2, 1), ).setIndexNames((0, "DISMAN-PING-MIB", "pingCtlOwnerIndex"), (0, "DISMAN-PING-MIB", "pingCtlTestName"))
if mibBuilder.loadTexts: pingCtlEntry.setDescription('Defines an entry in the pingCtlTable.  The first index\n           element, pingCtlOwnerIndex, is of type SnmpAdminString,\n           a textual convention that allows for use of the SNMPv3\n           View-Based Access Control Model (RFC 3415, VACM)\n           and that allows a management application to identify its\n           entries.  The second index, pingCtlTestName (also an\n           SnmpAdminString), enables the same management\n           application to have multiple outstanding requests.')
pingCtlOwnerIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)))
if mibBuilder.loadTexts: pingCtlOwnerIndex.setDescription("To facilitate the provisioning of access control by a\n          security administrator using the View-Based Access\n          Control Model (RFC 2575, VACM) for tables in which\n          multiple users may need to create or\n          modify entries independently, the initial index is used\n          as an 'owner index'.  Such an initial index has a syntax\n          of SnmpAdminString and can thus be trivially mapped to a\n          securityName or groupName defined in VACM, in\n          accordance with a security policy.\n\n          When used in conjunction with such a security policy, all\n          entries in the table belonging to a particular user (or\n          group) will have the same value for this initial index.\n          For a given user's entries in a particular table, the\n          object identifiers for the information in these entries\n          will have the same subidentifiers (except for the 'column'\n          subidentifier) up to the end of the encoded owner index.\n          To configure VACM to permit access to this portion of the\n          table, one would create vacmViewTreeFamilyTable entries\n          with the value of vacmViewTreeFamilySubtree including\n          the owner index portion, and vacmViewTreeFamilyMask\n          'wildcarding' the column subidentifier.  More elaborate\n          configurations are possible.")
pingCtlTestName = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)))
if mibBuilder.loadTexts: pingCtlTestName.setDescription('The name of the ping test.  This is locally unique, within\n           the scope of a pingCtlOwnerIndex.')
pingCtlTargetAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 3), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlTargetAddressType.setDescription('Specifies the type of host address to be used at a remote\n           host for performing a ping operation.')
pingCtlTargetAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 4), InetAddress().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlTargetAddress.setDescription('Specifies the host address to be used at a remote host for\n           performing a ping operation.  The host address type is\n           determined by the value of the corresponding\n           pingCtlTargetAddressType.\n\n           A value for this object MUST be set prior to transitioning\n           its corresponding pingCtlEntry to active(1) via\n           pingCtlRowStatus.')
pingCtlDataSize = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65507))).setUnits('octets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlDataSize.setDescription('Specifies the size of the data portion to be\n           transmitted in a ping operation, in octets.  Whether this\n           value can be applied depends on the selected\n           implementation method for performing a ping operation,\n           indicated by pingCtlType in the same conceptual row.\n           If the method used allows applying the value contained\n           in this object, then it MUST be applied.  If the specified\n           size is not appropriate for the chosen ping method, the\n           implementation SHOULD use whatever size (appropriate to\n           the method) is closest to the specified size.\n\n           The maximum value for this object was computed by\n           subtracting the smallest possible IP header size of\n           20 octets (IPv4 header with no options) and the UDP\n           header size of 8 octets from the maximum IP packet size.\n           An IP packet has a maximum size of 65535 octets\n           (excluding IPv6 Jumbograms).')
pingCtlTimeOut = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,60)).clone(3)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlTimeOut.setDescription('Specifies the time-out value, in seconds, for a\n           remote ping operation.')
pingCtlProbeCount = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,15)).clone(1)).setUnits('probes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlProbeCount.setDescription('Specifies the number of times to perform a ping\n           operation at a remote host as part of a single ping test.')
pingCtlAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),)).clone('disabled')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlAdminStatus.setDescription('Reflects the desired state that a pingCtlEntry should be\n           in:\n              enabled(1)  - Attempt to activate the test as defined by\n                            this pingCtlEntry.\n              disabled(2) - Deactivate the test as defined by this\n                            pingCtlEntry.\n\n           Refer to the corresponding pingResultsOperStatus to\n           determine the operational state of the test defined by\n           this entry.')
pingCtlDataFill = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,1024)).clone(hexValue="00")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlDataFill.setDescription('The content of this object is used together with the\n           corresponding pingCtlDataSize value to determine how to\n           fill the data portion of a probe packet.  The option of\n           selecting a data fill pattern can be useful when links\n           are compressed or have data pattern sensitivities.  The\n           contents of pingCtlDataFill should be repeated in a ping\n           packet when the size of the data portion of the ping\n           packet is greater than the size of pingCtlDataFill.')
pingCtlFrequency = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 10), Unsigned32()).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlFrequency.setDescription('The number of seconds to wait before repeating a ping test\n           as defined by the value of the various objects in the\n           corresponding row.\n\n           A single ping test consists of a series of ping probes.\n           The number of probes is determined by the value of the\n           corresponding pingCtlProbeCount object.  After a single\n           test is completed the number of seconds as defined by the\n           value of pingCtlFrequency MUST elapse before the\n           next ping test is started.\n\n           A value of 0 for this object implies that the test\n           as defined by the corresponding entry will not be\n           repeated.')
pingCtlMaxRows = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 11), Unsigned32().clone(50)).setUnits('rows').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlMaxRows.setDescription('The maximum number of corresponding entries allowed\n           in the pingProbeHistoryTable.  An implementation of this\n           MIB will remove the oldest corresponding entry in the\n           pingProbeHistoryTable to allow the addition of an\n           new entry once the number of corresponding rows in the\n           pingProbeHistoryTable reaches this value.\n\n           Old entries are not removed when a new test is\n           started.  Entries are added to the pingProbeHistoryTable\n           until pingCtlMaxRows is reached before entries begin to\n           be removed.\n\n           A value of 0 for this object disables creation of\n           pingProbeHistoryTable entries.')
pingCtlStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 12), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlStorageType.setDescription("The storage type for this conceptual row.\n           Conceptual rows having the value 'permanent' need not\n           allow write-access to any columnar objects in the row.")
pingCtlTrapGeneration = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 13), Bits().clone(namedValues=NamedValues(("probeFailure", 0), ("testFailure", 1), ("testCompletion", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlTrapGeneration.setDescription('The value of this object determines when and whether\n           to generate a notification for this entry:\n           probeFailure(0)   - Generate a pingProbeFailed\n               notification subject to the value of\n               pingCtlTrapProbeFailureFilter.  The object\n               pingCtlTrapProbeFailureFilter can be used\n               to specify the number of consecutive probe\n               failures that are required before a\n               pingProbeFailed notification can be generated.\n           testFailure(1)    - Generate a pingTestFailed\n               notification.  In this instance the object\n               pingCtlTrapTestFailureFilter can be used to\n               determine the number of probe failures that\n               signal when a test fails.\n           testCompletion(2) - Generate a pingTestCompleted\n               notification.\n\n           By default, no bits are set, indicating that\n           none of the above options is selected.')
pingCtlTrapProbeFailureFilter = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 14), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,15)).clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlTrapProbeFailureFilter.setDescription("The value of this object is used to determine when\n           to generate a pingProbeFailed NOTIFICATION.\n\n           Setting BIT probeFailure(0) of object\n           pingCtlTrapGeneration to '1' implies that a\n           pingProbeFailed NOTIFICATION is generated only when\n\n           a number of consecutive ping probes equal to the\n           value of pingCtlTrapProbeFailureFilter fail within\n           a given ping test.  After triggering the notification,\n           the probe failure counter is reset to zero.")
pingCtlTrapTestFailureFilter = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 15), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,15)).clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlTrapTestFailureFilter.setDescription("The value of this object is used to determine when\n           to generate a pingTestFailed NOTIFICATION.\n\n           Setting BIT testFailure(1) of object\n           pingCtlTrapGeneration to '1' implies that a\n           pingTestFailed NOTIFICATION is generated only when\n           a number of consecutive ping tests equal to the\n           value of pingCtlTrapProbeFailureFilter fail.\n           After triggering the notification, the test failure\n           counter is reset to zero.")
pingCtlType = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 16), ObjectIdentifier().clone((1, 3, 6, 1, 2, 1, 80, 3, 1))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlType.setDescription('The value of this object is used either to report or\n           to select the implementation method to be used for\n           calculating a ping response time.  The value of this\n           object MAY be selected from pingImplementationTypeDomains.\n\n           Additional implementation types SHOULD be allocated as\n           required by implementers of the DISMAN-PING-MIB under\n           their enterprise-specific registration point and not\n           beneath pingImplementationTypeDomains.')
pingCtlDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 17), SnmpAdminString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlDescr.setDescription('The purpose of this object is to provide a\n           descriptive name of the remote ping test.')
pingCtlSourceAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 18), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlSourceAddressType.setDescription('Specifies the type of the source address,\n           pingCtlSourceAddress, to be used at a remote host\n           when a ping operation is performed.')
pingCtlSourceAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 19), InetAddress().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlSourceAddress.setDescription("Use the specified IP address (which must be given in\n           numeric form, not as a hostname) as the source address\n           in outgoing probe packets.  On hosts with more than one\n           IP address, this option can be used to select the address\n           to be used.  If the IP address is not one of this\n           machine's interface addresses, an error is returned and\n           nothing is sent.  A zero-length octet string value for\n           this object disables source address specification.\n\n           The address type (InetAddressType) that relates to\n           this object is specified by the corresponding value\n           of pingCtlSourceAddressType.")
pingCtlIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 20), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlIfIndex.setDescription("Setting this object to an interface's ifIndex prior\n           to starting a remote ping operation directs\n           the ping probes to be transmitted over the\n           specified interface.  A value of zero for this object\n           means that this option is not enabled.")
pingCtlByPassRouteTable = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 21), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlByPassRouteTable.setDescription('The purpose of this object is to enable optional\n          bypassing the route table.  If enabled, the remote\n          host will bypass the normal routing tables and send\n          directly to a host on an attached network.  If the\n          host is not on a directly attached network, an\n          error is returned.  This option can be used to perform\n          the ping operation to a local host through an\n          interface that has no route defined (e.g., after the\n          interface was dropped by the routing daemon at the host).')
pingCtlDSField = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 22), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlDSField.setDescription('Specifies the value to store in the Type of Service\n           (TOS) octet in the IPv4 header or in the Traffic\n           Class octet in the IPv6 header, respectively, of the\n           IP packet used to encapsulate the ping probe.\n\n           The octet to be set in the IP header contains the\n           Differentiated Services (DS) Field in the six most\n           significant bits.\n\n           This option can be used to determine what effect an\n           explicit DS Field setting has on a ping response.\n           Not all values are legal or meaningful.  A value of 0\n           means that the function represented by this option is\n           not supported.  DS Field usage is often not supported\n           by IP implementations, and not all values are supported.\n           Refer to RFC 2474 and RFC 3260 for guidance on usage of\n           this field.')
pingCtlRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 2, 1, 23), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pingCtlRowStatus.setDescription("This object allows entries to be created and deleted\n           in the pingCtlTable.  Deletion of an entry in this\n           table results in the deletion of all corresponding (same\n           pingCtlOwnerIndex and pingCtlTestName index values)\n           pingResultsTable and pingProbeHistoryTable entries.\n\n           A value MUST be specified for pingCtlTargetAddress\n           prior to acceptance of a transition to active(1) state.\n\n           When a value for pingCtlTargetAddress is set,\n           the value of object pingCtlRowStatus changes\n           from notReady(3) to notInService(2).\n\n           Activation of a remote ping operation is controlled\n           via pingCtlAdminStatus, not by changing\n           this object's value to active(1).\n\n           Transitions in and out of active(1) state are not\n           allowed while an entry's pingResultsOperStatus is\n           active(1), with the exception that deletion of\n           an entry in this table by setting its RowStatus\n           object to destroy(6) will stop an active\n           ping operation.\n\n           The operational state of a ping operation\n           can be determined by examination of its\n           pingResultsOperStatus object.")
pingResultsTable = MibTable((1, 3, 6, 1, 2, 1, 80, 1, 3), )
if mibBuilder.loadTexts: pingResultsTable.setDescription('Defines the Ping Results Table for providing\n           the capability of performing ping operations at\n           a remote host.  The results of these operations are\n           stored in the pingResultsTable and the pingProbeHistoryTable.\n\n           An entry is added to the pingResultsTable when an\n           pingCtlEntry is started by successful transition\n           of its pingCtlAdminStatus object to enabled(1).\n\n           If the object pingCtlAdminStatus already has the value\n           enabled(1), and if the corresponding pingResultsOperStatus\n           object has the value completed(3), then successfully writing\n           enabled(1) to object pingCtlAdminStatus re-initializes the\n           already existing entry in the pingResultsTable.  The values\n           of objects in the re-initialized entry are the same as the\n           values of objects in a new entry would be.\n\n           An entry is removed from the pingResultsTable when\n           its corresponding pingCtlEntry is deleted.')
pingResultsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 80, 1, 3, 1), ).setIndexNames((0, "DISMAN-PING-MIB", "pingCtlOwnerIndex"), (0, "DISMAN-PING-MIB", "pingCtlTestName"))
if mibBuilder.loadTexts: pingResultsEntry.setDescription('Defines an entry in the pingResultsTable.  The\n           pingResultsTable has the same indexing as the\n           pingCtlTable so that a pingResultsEntry\n           corresponds to the pingCtlEntry that caused it to\n           be created.')
pingResultsOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("completed", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsOperStatus.setDescription('Reflects the operational state of a pingCtlEntry:\n\n              enabled(1)    - Test is active.\n              disabled(2)   - Test has stopped.\n              completed(3)  - Test is completed.')
pingResultsIpTargetAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 2), InetAddressType().clone('unknown')).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsIpTargetAddressType.setDescription('This object indicates the type of address stored\n           in the corresponding pingResultsIpTargetAddress\n           object.')
pingResultsIpTargetAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 3), InetAddress().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsIpTargetAddress.setDescription('This object reports the IP address associated\n           with a pingCtlTargetAddress value when the destination\n           address is specified as a DNS name.  The value of\n           this object should be a zero-length octet string\n           when a DNS name is not specified or when a\n           specified DNS name fails to resolve.\n\n           The address type (InetAddressType) that relates to\n           this object is specified by the corresponding value\n           of pingResultsIpTargetAddressType.')
pingResultsMinRtt = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 4), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsMinRtt.setDescription('The minimum ping round-trip-time (RTT) received.  A value\n           of 0 for this object implies that no RTT has been received.')
pingResultsMaxRtt = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 5), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsMaxRtt.setDescription('The maximum ping round-trip-time (RTT) received.  A value\n           of 0 for this object implies that no RTT has been received.')
pingResultsAverageRtt = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 6), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsAverageRtt.setDescription('The current average ping round-trip-time (RTT).')
pingResultsProbeResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 7), Gauge32()).setUnits('responses').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsProbeResponses.setDescription('Number of responses received for the corresponding\n           pingCtlEntry and pingResultsEntry.  The value of this object\n           MUST be reported as 0 when no probe responses have been\n           received.')
pingResultsSentProbes = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 8), Gauge32()).setUnits('probes').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsSentProbes.setDescription('The value of this object reflects the number of probes sent\n           for the corresponding pingCtlEntry and pingResultsEntry.\n           The value of this object MUST be reported as 0 when no probes\n           have been sent.')
pingResultsRttSumOfSquares = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 9), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsRttSumOfSquares.setDescription('This object contains the sum of the squares for all ping\n           responses received.  Its purpose is to enable standard\n           deviation calculation.  The value of this object MUST\n           be reported as 0 when no ping responses have been\n           received.')
pingResultsLastGoodProbe = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 3, 1, 10), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingResultsLastGoodProbe.setDescription('Date and time when the last response was received for\n           a probe.')
pingProbeHistoryTable = MibTable((1, 3, 6, 1, 2, 1, 80, 1, 4), )
if mibBuilder.loadTexts: pingProbeHistoryTable.setDescription('Defines a table for storing the results of ping\n           operations.  The number of entries in this table is\n           limited per entry in the pingCtlTable by the value\n           of the corresponding pingCtlMaxRows object.\n\n           An entry in this table is created when the result of\n           a ping probe is determined.  The initial 2 instance\n           identifier index values identify the pingCtlEntry\n           that a probe result (pingProbeHistoryEntry) belongs\n           to.  An entry is removed from this table when\n           its corresponding pingCtlEntry is deleted.\n\n           An implementation of this MIB will remove the oldest\n           entry in the pingProbeHistoryTable of the\n           corresponding entry in the pingCtlTable to allow\n           the addition of an new entry once the number of rows\n           in the pingProbeHistoryTable reaches the value\n           specified by pingCtlMaxRows for the corresponding\n           entry in the pingCtlTable.')
pingProbeHistoryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 80, 1, 4, 1), ).setIndexNames((0, "DISMAN-PING-MIB", "pingCtlOwnerIndex"), (0, "DISMAN-PING-MIB", "pingCtlTestName"), (0, "DISMAN-PING-MIB", "pingProbeHistoryIndex"))
if mibBuilder.loadTexts: pingProbeHistoryEntry.setDescription('Defines an entry in the pingProbeHistoryTable.\n           The first two index elements identify the\n           pingCtlEntry that a pingProbeHistoryEntry belongs\n           to.  The third index element selects a single\n           probe result.')
pingProbeHistoryIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: pingProbeHistoryIndex.setDescription("An entry in this table is created when the result of\n           a ping probe is determined.  The initial 2 instance\n           identifier index values identify the pingCtlEntry\n           that a probe result (pingProbeHistoryEntry) belongs\n           to.\n\n           An implementation MUST start assigning\n           pingProbeHistoryIndex values at 1 and wrap after\n           exceeding the maximum possible value as defined by\n           the limit of this object ('ffffffff'h).")
pingProbeHistoryResponse = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 4, 1, 2), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pingProbeHistoryResponse.setDescription('The amount of time measured in milliseconds from when\n           a probe was sent to when its response was received or\n           when it timed out.  The value of this object is reported\n           as 0 when it is not possible to transmit a probe.')
pingProbeHistoryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 4, 1, 3), OperationResponseStatus()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingProbeHistoryStatus.setDescription('The result of a particular probe done by a remote host.')
pingProbeHistoryLastRC = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 4, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingProbeHistoryLastRC.setDescription('The last implementation-method-specific reply code received.\n           If the ICMP Echo capability is being used, then a successful\n           probe ends when an ICMP response is received that contains\n           the code ICMP_ECHOREPLY(0).  The ICMP codes are maintained\n           by IANA.  Standardized ICMP codes are listed at\n           http://www.iana.org/assignments/icmp-parameters.\n           The ICMPv6 codes are listed at\n           http://www.iana.org/assignments/icmpv6-parameters.')
pingProbeHistoryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 80, 1, 4, 1, 5), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pingProbeHistoryTime.setDescription('Timestamp for when this probe result was determined.')
pingProbeFailed = NotificationType((1, 3, 6, 1, 2, 1, 80, 0, 1)).setObjects(*(("DISMAN-PING-MIB", "pingCtlTargetAddressType"), ("DISMAN-PING-MIB", "pingCtlTargetAddress"), ("DISMAN-PING-MIB", "pingResultsOperStatus"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddressType"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddress"), ("DISMAN-PING-MIB", "pingResultsMinRtt"), ("DISMAN-PING-MIB", "pingResultsMaxRtt"), ("DISMAN-PING-MIB", "pingResultsAverageRtt"), ("DISMAN-PING-MIB", "pingResultsProbeResponses"), ("DISMAN-PING-MIB", "pingResultsSentProbes"), ("DISMAN-PING-MIB", "pingResultsRttSumOfSquares"), ("DISMAN-PING-MIB", "pingResultsLastGoodProbe"),))
if mibBuilder.loadTexts: pingProbeFailed.setDescription('Generated when a probe failure is detected, when the\n             corresponding pingCtlTrapGeneration object is set to\n             probeFailure(0), subject to the value of\n             pingCtlTrapProbeFailureFilter.  The object\n             pingCtlTrapProbeFailureFilter can be used to specify the\n             number of consecutive probe failures that are required\n             before this notification can be generated.')
pingTestFailed = NotificationType((1, 3, 6, 1, 2, 1, 80, 0, 2)).setObjects(*(("DISMAN-PING-MIB", "pingCtlTargetAddressType"), ("DISMAN-PING-MIB", "pingCtlTargetAddress"), ("DISMAN-PING-MIB", "pingResultsOperStatus"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddressType"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddress"), ("DISMAN-PING-MIB", "pingResultsMinRtt"), ("DISMAN-PING-MIB", "pingResultsMaxRtt"), ("DISMAN-PING-MIB", "pingResultsAverageRtt"), ("DISMAN-PING-MIB", "pingResultsProbeResponses"), ("DISMAN-PING-MIB", "pingResultsSentProbes"), ("DISMAN-PING-MIB", "pingResultsRttSumOfSquares"), ("DISMAN-PING-MIB", "pingResultsLastGoodProbe"),))
if mibBuilder.loadTexts: pingTestFailed.setDescription('Generated when a ping test is determined to have failed,\n             when the corresponding pingCtlTrapGeneration object is\n             set to testFailure(1).  In this instance,\n             pingCtlTrapTestFailureFilter should specify the number of\n             probes in a test required to have failed in order to\n             consider the test failed.')
pingTestCompleted = NotificationType((1, 3, 6, 1, 2, 1, 80, 0, 3)).setObjects(*(("DISMAN-PING-MIB", "pingCtlTargetAddressType"), ("DISMAN-PING-MIB", "pingCtlTargetAddress"), ("DISMAN-PING-MIB", "pingResultsOperStatus"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddressType"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddress"), ("DISMAN-PING-MIB", "pingResultsMinRtt"), ("DISMAN-PING-MIB", "pingResultsMaxRtt"), ("DISMAN-PING-MIB", "pingResultsAverageRtt"), ("DISMAN-PING-MIB", "pingResultsProbeResponses"), ("DISMAN-PING-MIB", "pingResultsSentProbes"), ("DISMAN-PING-MIB", "pingResultsRttSumOfSquares"), ("DISMAN-PING-MIB", "pingResultsLastGoodProbe"),))
if mibBuilder.loadTexts: pingTestCompleted.setDescription('Generated at the completion of a ping test when the\n             corresponding pingCtlTrapGeneration object has the\n             testCompletion(2) bit set.')
pingCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 80, 2, 1))
pingGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 80, 2, 2))
pingFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 80, 2, 1, 2)).setObjects(*(("DISMAN-PING-MIB", "pingMinimumGroup"), ("DISMAN-PING-MIB", "pingCtlRowStatusGroup"), ("DISMAN-PING-MIB", "pingHistoryGroup"), ("DISMAN-PING-MIB", "pingNotificationsGroup"),))
if mibBuilder.loadTexts: pingFullCompliance.setDescription('The compliance statement for SNMP entities that\n               fully implement the DISMAN-PING-MIB.')
pingMinimumCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 80, 2, 1, 3)).setObjects(*(("DISMAN-PING-MIB", "pingMinimumGroup"), ("DISMAN-PING-MIB", "pingCtlRowStatusGroup"), ("DISMAN-PING-MIB", "pingHistoryGroup"), ("DISMAN-PING-MIB", "pingNotificationsGroup"),))
if mibBuilder.loadTexts: pingMinimumCompliance.setDescription('The minimum compliance statement for SNMP entities\n               that implement the minimal subset of the\n               DISMAN-PING-MIB.  Implementors might choose this\n               subset for small devices with limited resources.')
pingCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 80, 2, 1, 1)).setObjects(*(("DISMAN-PING-MIB", "pingGroup"), ("DISMAN-PING-MIB", "pingNotificationsGroup"), ("DISMAN-PING-MIB", "pingTimeStampGroup"),))
if mibBuilder.loadTexts: pingCompliance.setDescription('The compliance statement for the DISMAN-PING-MIB.  This\n               compliance statement has been deprecated because the\n               group pingGroup and the pingTimeStampGroup have been\n               split and deprecated.  The pingFullCompliance statement\n               is semantically identical to the deprecated\n               pingCompliance statement.')
pingMinimumGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 80, 2, 2, 4)).setObjects(*(("DISMAN-PING-MIB", "pingMaxConcurrentRequests"), ("DISMAN-PING-MIB", "pingCtlTargetAddressType"), ("DISMAN-PING-MIB", "pingCtlTargetAddress"), ("DISMAN-PING-MIB", "pingCtlDataSize"), ("DISMAN-PING-MIB", "pingCtlTimeOut"), ("DISMAN-PING-MIB", "pingCtlProbeCount"), ("DISMAN-PING-MIB", "pingCtlAdminStatus"), ("DISMAN-PING-MIB", "pingCtlDataFill"), ("DISMAN-PING-MIB", "pingCtlFrequency"), ("DISMAN-PING-MIB", "pingCtlMaxRows"), ("DISMAN-PING-MIB", "pingCtlStorageType"), ("DISMAN-PING-MIB", "pingCtlTrapGeneration"), ("DISMAN-PING-MIB", "pingCtlTrapProbeFailureFilter"), ("DISMAN-PING-MIB", "pingCtlTrapTestFailureFilter"), ("DISMAN-PING-MIB", "pingCtlType"), ("DISMAN-PING-MIB", "pingCtlDescr"), ("DISMAN-PING-MIB", "pingCtlByPassRouteTable"), ("DISMAN-PING-MIB", "pingCtlSourceAddressType"), ("DISMAN-PING-MIB", "pingCtlSourceAddress"), ("DISMAN-PING-MIB", "pingCtlIfIndex"), ("DISMAN-PING-MIB", "pingCtlDSField"), ("DISMAN-PING-MIB", "pingResultsOperStatus"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddressType"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddress"), ("DISMAN-PING-MIB", "pingResultsMinRtt"), ("DISMAN-PING-MIB", "pingResultsMaxRtt"), ("DISMAN-PING-MIB", "pingResultsAverageRtt"), ("DISMAN-PING-MIB", "pingResultsProbeResponses"), ("DISMAN-PING-MIB", "pingResultsSentProbes"), ("DISMAN-PING-MIB", "pingResultsRttSumOfSquares"), ("DISMAN-PING-MIB", "pingResultsLastGoodProbe"),))
if mibBuilder.loadTexts: pingMinimumGroup.setDescription('The group of objects that constitute the remote ping\n          capability.')
pingCtlRowStatusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 80, 2, 2, 5)).setObjects(*(("DISMAN-PING-MIB", "pingCtlRowStatus"),))
if mibBuilder.loadTexts: pingCtlRowStatusGroup.setDescription('The RowStatus object of the pingCtlTable.')
pingHistoryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 80, 2, 2, 6)).setObjects(*(("DISMAN-PING-MIB", "pingProbeHistoryResponse"), ("DISMAN-PING-MIB", "pingProbeHistoryStatus"), ("DISMAN-PING-MIB", "pingProbeHistoryLastRC"), ("DISMAN-PING-MIB", "pingProbeHistoryTime"),))
if mibBuilder.loadTexts: pingHistoryGroup.setDescription('The group of objects that constitute the history\n          capability.')
pingNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 80, 2, 2, 3)).setObjects(*(("DISMAN-PING-MIB", "pingProbeFailed"), ("DISMAN-PING-MIB", "pingTestFailed"), ("DISMAN-PING-MIB", "pingTestCompleted"),))
if mibBuilder.loadTexts: pingNotificationsGroup.setDescription('The notification that are required to be supported by\n          implementations of this MIB.')
pingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 80, 2, 2, 1)).setObjects(*(("DISMAN-PING-MIB", "pingMaxConcurrentRequests"), ("DISMAN-PING-MIB", "pingCtlTargetAddressType"), ("DISMAN-PING-MIB", "pingCtlTargetAddress"), ("DISMAN-PING-MIB", "pingCtlDataSize"), ("DISMAN-PING-MIB", "pingCtlTimeOut"), ("DISMAN-PING-MIB", "pingCtlProbeCount"), ("DISMAN-PING-MIB", "pingCtlAdminStatus"), ("DISMAN-PING-MIB", "pingCtlDataFill"), ("DISMAN-PING-MIB", "pingCtlFrequency"), ("DISMAN-PING-MIB", "pingCtlMaxRows"), ("DISMAN-PING-MIB", "pingCtlStorageType"), ("DISMAN-PING-MIB", "pingCtlTrapGeneration"), ("DISMAN-PING-MIB", "pingCtlTrapProbeFailureFilter"), ("DISMAN-PING-MIB", "pingCtlTrapTestFailureFilter"), ("DISMAN-PING-MIB", "pingCtlType"), ("DISMAN-PING-MIB", "pingCtlDescr"), ("DISMAN-PING-MIB", "pingCtlByPassRouteTable"), ("DISMAN-PING-MIB", "pingCtlSourceAddressType"), ("DISMAN-PING-MIB", "pingCtlSourceAddress"), ("DISMAN-PING-MIB", "pingCtlIfIndex"), ("DISMAN-PING-MIB", "pingCtlDSField"), ("DISMAN-PING-MIB", "pingCtlRowStatus"), ("DISMAN-PING-MIB", "pingResultsOperStatus"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddressType"), ("DISMAN-PING-MIB", "pingResultsIpTargetAddress"), ("DISMAN-PING-MIB", "pingResultsMinRtt"), ("DISMAN-PING-MIB", "pingResultsMaxRtt"), ("DISMAN-PING-MIB", "pingResultsAverageRtt"), ("DISMAN-PING-MIB", "pingResultsProbeResponses"), ("DISMAN-PING-MIB", "pingResultsSentProbes"), ("DISMAN-PING-MIB", "pingResultsRttSumOfSquares"), ("DISMAN-PING-MIB", "pingProbeHistoryResponse"), ("DISMAN-PING-MIB", "pingProbeHistoryStatus"), ("DISMAN-PING-MIB", "pingProbeHistoryLastRC"),))
if mibBuilder.loadTexts: pingGroup.setDescription('The group of objects that constitute the remote ping\n          capability.')
pingTimeStampGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 80, 2, 2, 2)).setObjects(*(("DISMAN-PING-MIB", "pingResultsLastGoodProbe"), ("DISMAN-PING-MIB", "pingProbeHistoryTime"),))
if mibBuilder.loadTexts: pingTimeStampGroup.setDescription('The group of DateAndTime objects.')
mibBuilder.exportSymbols("DISMAN-PING-MIB", pingProbeHistoryEntry=pingProbeHistoryEntry, pingCtlEntry=pingCtlEntry, pingTestCompleted=pingTestCompleted, pingCtlTargetAddress=pingCtlTargetAddress, pingTestFailed=pingTestFailed, pingGroup=pingGroup, pingSnmpQuery=pingSnmpQuery, pingFullCompliance=pingFullCompliance, pingCtlOwnerIndex=pingCtlOwnerIndex, pingCtlType=pingCtlType, pingCtlRowStatusGroup=pingCtlRowStatusGroup, pingProbeHistoryLastRC=pingProbeHistoryLastRC, pingResultsOperStatus=pingResultsOperStatus, pingCtlTestName=pingCtlTestName, pingCtlRowStatus=pingCtlRowStatus, OperationResponseStatus=OperationResponseStatus, pingIcmpEcho=pingIcmpEcho, pingCtlByPassRouteTable=pingCtlByPassRouteTable, pingResultsLastGoodProbe=pingResultsLastGoodProbe, pingResultsMaxRtt=pingResultsMaxRtt, pingProbeHistoryResponse=pingProbeHistoryResponse, pingCtlDataFill=pingCtlDataFill, pingCtlTrapTestFailureFilter=pingCtlTrapTestFailureFilter, pingResultsTable=pingResultsTable, pingCtlTable=pingCtlTable, pingHistoryGroup=pingHistoryGroup, pingCtlFrequency=pingCtlFrequency, pingCtlDSField=pingCtlDSField, pingImplementationTypeDomains=pingImplementationTypeDomains, PYSNMP_MODULE_ID=pingMIB, pingResultsIpTargetAddress=pingResultsIpTargetAddress, pingResultsAverageRtt=pingResultsAverageRtt, pingCtlDataSize=pingCtlDataSize, pingNotifications=pingNotifications, pingProbeHistoryTime=pingProbeHistoryTime, pingProbeHistoryStatus=pingProbeHistoryStatus, pingUdpEcho=pingUdpEcho, pingResultsEntry=pingResultsEntry, pingResultsIpTargetAddressType=pingResultsIpTargetAddressType, pingMIB=pingMIB, pingCtlTrapGeneration=pingCtlTrapGeneration, pingCtlDescr=pingCtlDescr, pingCompliances=pingCompliances, pingMinimumCompliance=pingMinimumCompliance, pingTimeStampGroup=pingTimeStampGroup, pingGroups=pingGroups, pingObjects=pingObjects, pingProbeHistoryTable=pingProbeHistoryTable, pingProbeHistoryIndex=pingProbeHistoryIndex, pingResultsSentProbes=pingResultsSentProbes, pingCtlTrapProbeFailureFilter=pingCtlTrapProbeFailureFilter, pingCtlMaxRows=pingCtlMaxRows, pingCtlAdminStatus=pingCtlAdminStatus, pingCtlTargetAddressType=pingCtlTargetAddressType, pingNotificationsGroup=pingNotificationsGroup, pingMaxConcurrentRequests=pingMaxConcurrentRequests, pingResultsMinRtt=pingResultsMinRtt, pingCtlTimeOut=pingCtlTimeOut, pingCtlProbeCount=pingCtlProbeCount, pingResultsRttSumOfSquares=pingResultsRttSumOfSquares, pingCompliance=pingCompliance, pingCtlStorageType=pingCtlStorageType, pingConformance=pingConformance, pingProbeFailed=pingProbeFailed, pingCtlSourceAddressType=pingCtlSourceAddressType, pingCtlIfIndex=pingCtlIfIndex, pingResultsProbeResponses=pingResultsProbeResponses, pingCtlSourceAddress=pingCtlSourceAddress, pingTcpConnectionAttempt=pingTcpConnectionAttempt, pingMinimumGroup=pingMinimumGroup)



#
# PySNMP MIB module IPS-AUTH-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IPS-AUTH-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:18:17 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint")
( AddressFamilyNumbers, ) = mibBuilder.importSymbols("IANA-ADDRESS-FAMILY-NUMBERS-MIB", "AddressFamilyNumbers")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( IpAddress, NotificationType, iso, Counter32, Integer32, mib_2, Gauge32, ModuleIdentity, Unsigned32, TimeTicks, MibIdentifier, Counter64, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "NotificationType", "iso", "Counter32", "Integer32", "mib-2", "Gauge32", "ModuleIdentity", "Unsigned32", "TimeTicks", "MibIdentifier", "Counter64", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits")
( AutonomousType, TextualConvention, StorageType, DisplayString, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "AutonomousType", "TextualConvention", "StorageType", "DisplayString", "RowStatus")
ipsAuthMibModule = ModuleIdentity((1, 3, 6, 1, 2, 1, 141)).setRevisions(("2006-05-22 00:00",))
if mibBuilder.loadTexts: ipsAuthMibModule.setLastUpdated('200605220000Z')
if mibBuilder.loadTexts: ipsAuthMibModule.setOrganization('IETF IPS Working Group')
if mibBuilder.loadTexts: ipsAuthMibModule.setContactInfo('\n    Mark Bakke\n    Postal: Cisco Systems, Inc\n    7900 International Drive, Suite 400\n    Bloomington, MN\n    USA 55425\n\n    E-mail: mbakke@cisco.com\n\n    James Muchow\n    Postal: Qlogic Corp.\n    6321 Bury Dr.\n    Eden Prairie, MN\n    USA 55346\n\n    E-Mail: james.muchow@qlogic.com')
if mibBuilder.loadTexts: ipsAuthMibModule.setDescription('The IP Storage Authorization MIB module.\n         Copyright (C) The Internet Society (2006).  This version of\n         this MIB module is part of RFC 4545;  see the RFC itself for\n         full legal notices.')
ipsAuthNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 0))
ipsAuthObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1))
ipsAuthConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 2))
class IpsAuthAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

ipsAuthDescriptors = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 1))
ipsAuthMethodTypes = ObjectIdentity((1, 3, 6, 1, 2, 1, 141, 1, 1, 1))
if mibBuilder.loadTexts: ipsAuthMethodTypes.setDescription('Registration point for Authentication Method Types.')
ipsAuthMethodNone = ObjectIdentity((1, 3, 6, 1, 2, 1, 141, 1, 1, 1, 1))
if mibBuilder.loadTexts: ipsAuthMethodNone.setDescription('The authoritative identifier when no authentication\n        method is used.')
ipsAuthMethodSrp = ObjectIdentity((1, 3, 6, 1, 2, 1, 141, 1, 1, 1, 2))
if mibBuilder.loadTexts: ipsAuthMethodSrp.setDescription('The authoritative identifier when the authentication\n        method is SRP.')
ipsAuthMethodChap = ObjectIdentity((1, 3, 6, 1, 2, 1, 141, 1, 1, 1, 3))
if mibBuilder.loadTexts: ipsAuthMethodChap.setDescription('The authoritative identifier when the authentication\n        method is CHAP.')
ipsAuthMethodKerberos = ObjectIdentity((1, 3, 6, 1, 2, 1, 141, 1, 1, 1, 4))
if mibBuilder.loadTexts: ipsAuthMethodKerberos.setDescription('The authoritative identifier when the authentication\n        method is Kerberos.')
ipsAuthInstance = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 2))
ipsAuthInstanceAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 2, 2), )
if mibBuilder.loadTexts: ipsAuthInstanceAttributesTable.setDescription('A list of Authorization instances present on the system.')
ipsAuthInstanceAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 2, 2, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"))
if mibBuilder.loadTexts: ipsAuthInstanceAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to a particular Authorization instance.')
ipsAuthInstIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 2, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: ipsAuthInstIndex.setDescription('An arbitrary integer used to uniquely identify a\n        particular authorization instance.  This index value\n        must not be modified or reused by an agent unless\n        a reboot has occurred.  An agent should attempt to\n        keep this value persistent across reboots.')
ipsAuthInstDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 2, 2, 1, 2), SnmpAdminString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipsAuthInstDescr.setDescription('A character string, determined by the implementation to\n        describe the authorization instance.  When only a single\n        instance is present, this object may be set to the\n        zero-length string; with multiple authorization\n        instances, it must be set to a unique value in an\n        implementation-dependent manner to describe the purpose\n        of the respective instance.  If this is deployed in a\n        master agent with more than one subagent implementing\n        this MIB module, the master agent is responsible for\n        ensuring that this object is unique across all\n        subagents.')
ipsAuthInstStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 2, 2, 1, 3), StorageType().clone('volatile')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipsAuthInstStorageType.setDescription("The storage type for all read-write objects within this\n         row.  Rows in this table are always created via an\n         external process, and may have a storage type of readOnly\n         or permanent.  Conceptual rows having the value 'permanent'\n         need not allow write access to any columnar objects in\n         the row.\n\n         If this object has the value 'volatile', modifications\n         to read-write objects in this row are not persistent\n         across reboots.  If this object has the value\n         'nonVolatile', modifications to objects in this row\n         are persistent.\n\n         An implementation may choose to allow this object\n         to be set to either 'nonVolatile' or 'volatile',\n         allowing the management application to choose this\n         behavior.")
ipsAuthIdentity = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 3))
ipsAuthIdentAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 3, 1), )
if mibBuilder.loadTexts: ipsAuthIdentAttributesTable.setDescription('A list of user identities, each belonging to a\n        particular ipsAuthInstance.')
ipsAuthIdentAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 3, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"))
if mibBuilder.loadTexts: ipsAuthIdentAttributesEntry.setDescription('An entry (row) containing management information\n        describing a user identity within an authorization\n        instance on this node.')
ipsAuthIdentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 3, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: ipsAuthIdentIndex.setDescription('An arbitrary integer used to uniquely identify a\n        particular identity instance within an authorization\n        instance present on the node.  This index value\n        must not be modified or reused by an agent unless\n        a reboot has occurred.  An agent should attempt to\n        keep this value persistent across reboots.')
ipsAuthIdentDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 3, 1, 1, 2), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentDescription.setDescription('A character string describing this particular identity.')
ipsAuthIdentRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 3, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The value of\n        ipsAuthIdentDescription may be set while\n        ipsAuthIdentRowStatus is 'active'.")
ipsAuthIdentStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 3, 1, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthIdentityName = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 4))
ipsAuthIdentNameAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 4, 1), )
if mibBuilder.loadTexts: ipsAuthIdentNameAttributesTable.setDescription('A list of unique names that can be used to positively\n        identify a particular user identity.')
ipsAuthIdentNameAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 4, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentNameIndex"))
if mibBuilder.loadTexts: ipsAuthIdentNameAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to a unique identity name, which can be used\n        to identify a user identity within a particular\n        authorization instance.')
ipsAuthIdentNameIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 4, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: ipsAuthIdentNameIndex.setDescription('An arbitrary integer used to uniquely identify a\n        particular identity name instance within an\n        ipsAuthIdentity within an authorization instance.\n        This index value must not be modified or reused by\n        an agent unless a reboot has occurred.  An agent\n        should attempt to keep this value persistent across\n        reboots.')
ipsAuthIdentName = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 4, 1, 1, 2), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentName.setDescription('A character string that is the unique name of an\n        identity that may be used to identify this ipsAuthIdent\n        entry.')
ipsAuthIdentNameRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 4, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentNameRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The value of\n        ipsAuthIdentName may be set when this value is 'active'.")
ipsAuthIdentNameStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 4, 1, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentNameStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthIdentityAddress = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 5))
ipsAuthIdentAddrAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 5, 1), )
if mibBuilder.loadTexts: ipsAuthIdentAddrAttributesTable.setDescription('A list of address ranges that are allowed to serve\n        as the endpoint addresses of a particular identity.\n        An address range includes a starting and ending address\n        and an optional netmask, and an address type indicator,\n        which can specify whether the address is IPv4, IPv6,\n        FC-WWPN, or FC-WWNN.')
ipsAuthIdentAddrAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentAddrIndex"))
if mibBuilder.loadTexts: ipsAuthIdentAddrAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to an address range that is used as part\n        of the authorization of an identity\n        within an authorization instance on this node.')
ipsAuthIdentAddrIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: ipsAuthIdentAddrIndex.setDescription('An arbitrary integer used to uniquely identify a\n        particular ipsAuthIdentAddress instance within an\n        ipsAuthIdentity within an authorization instance\n        present on the node.\n        This index value must not be modified or reused by\n        an agent unless a reboot has occurred.  An agent\n        should attempt to keep this value persistent across\n        reboots.')
ipsAuthIdentAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1, 2), AddressFamilyNumbers()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentAddrType.setDescription('The address types used in the ipsAuthIdentAddrStart\n        and ipsAuthAddrEnd objects.  This type is taken\n        from the IANA address family types.')
ipsAuthIdentAddrStart = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1, 3), IpsAuthAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentAddrStart.setDescription('The starting address of the allowed address range.\n        The format of this object is determined by\n        ipsAuthIdentAddrType.')
ipsAuthIdentAddrEnd = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1, 4), IpsAuthAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentAddrEnd.setDescription('The ending address of the allowed address range.\n        If the ipsAuthIdentAddrEntry specifies a single\n        address, this shall match the ipsAuthIdentAddrStart.\n        The format of this object is determined by\n        ipsAuthIdentAddrType.')
ipsAuthIdentAddrRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentAddrRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The values of\n        ipsAuthIdentAddrStart and ipsAuthIdentAddrEnd may be set\n        when this value is 'active'.  The value of\n        ipsAuthIdentAddrType may not be set when this value is\n        'active'.")
ipsAuthIdentAddrStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 5, 1, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthIdentAddrStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthCredential = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 6))
ipsAuthCredentialAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 6, 1), )
if mibBuilder.loadTexts: ipsAuthCredentialAttributesTable.setDescription('A list of credentials related to user identities\n        that are allowed as valid authenticators of the\n        particular identity.')
ipsAuthCredentialAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 6, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"), (0, "IPS-AUTH-MIB", "ipsAuthCredIndex"))
if mibBuilder.loadTexts: ipsAuthCredentialAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to a credential that verifies a user\n        identity within an authorization instance.\n\n\n\n        To provide complete information in this MIB for a credential,\n        the management station must not only create the row in this\n        table but must also create a row in another table, where the\n        other table is determined by the value of\n        ipsAuthCredAuthMethod, e.g., if ipsAuthCredAuthMethod has the\n        value ipsAuthMethodChap, a row must be created in the\n        ipsAuthCredChapAttributesTable.')
ipsAuthCredIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 6, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: ipsAuthCredIndex.setDescription('An arbitrary integer used to uniquely identify a\n        particular Credential instance within an instance\n        present on the node.\n        This index value must not be modified or reused by\n        an agent unless a reboot has occurred.  An agent\n        should attempt to keep this value persistent across\n        reboots.')
ipsAuthCredAuthMethod = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 6, 1, 1, 2), AutonomousType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredAuthMethod.setDescription('This object contains an OBJECT IDENTIFIER\n        that identifies the authentication method\n        used with this credential.\n\n        When a row is created in this table, a corresponding\n        row must be created by the management station\n        in a corresponding table specified by this value.\n\n        When a row is deleted from this table, the corresponding\n        row must be automatically deleted by the agent in\n        the corresponding table specified by this value.\n\n\n\n\n        If the value of this object is ipsAuthMethodNone, no\n        corresponding rows are created or deleted from other\n        tables.\n\n        Some standardized values for this object are defined\n        within the ipsAuthMethodTypes subtree.')
ipsAuthCredRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 6, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The value of\n        ipsAuthCredAuthMethod must not be changed while this row\n        is 'active'.")
ipsAuthCredStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 6, 1, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthCredChap = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 7))
ipsAuthCredChapAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 7, 1), )
if mibBuilder.loadTexts: ipsAuthCredChapAttributesTable.setDescription("A list of CHAP attributes for credentials that\n        use ipsAuthMethodChap as their ipsAuthCredAuthMethod.\n\n        A row in this table can only exist when an instance of\n        the ipsAuthCredAuthMethod object exists (or is created\n\n\n\n        simultaneously) having the same instance identifiers\n        and a value of 'ipsAuthMethodChap'.")
ipsAuthCredChapAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 7, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"), (0, "IPS-AUTH-MIB", "ipsAuthCredIndex"))
if mibBuilder.loadTexts: ipsAuthCredChapAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to a credential that uses\n        ipsAuthMethodChap as their ipsAuthCredAuthMethod.\n\n        When a row is created in ipsAuthCredentialAttributesTable\n        with ipsAuthCredAuthMethod = ipsAuthCredChap, the\n        management station must create a corresponding row\n        in this table.\n\n        When a row is deleted from ipsAuthCredentialAttributesTable\n        with ipsAuthCredAuthMethod = ipsAuthCredChap, the\n        agent must delete the corresponding row (if any) in\n        this table.')
ipsAuthCredChapUserName = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 7, 1, 1, 1), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredChapUserName.setDescription('A character string containing the CHAP user name for this\n        credential.')
ipsAuthCredChapRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 7, 1, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredChapRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The value of\n        ipsAuthCredChapUserName may be changed while this row\n        is 'active'.")
ipsAuthCredChapStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 7, 1, 1, 3), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredChapStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthCredSrp = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 8))
ipsAuthCredSrpAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 8, 1), )
if mibBuilder.loadTexts: ipsAuthCredSrpAttributesTable.setDescription("A list of SRP attributes for credentials that\n        use ipsAuthMethodSrp as its ipsAuthCredAuthMethod.\n\n        A row in this table can only exist when an instance of\n        the ipsAuthCredAuthMethod object exists (or is created\n        simultaneously) having the same instance identifiers\n        and a value of 'ipsAuthMethodSrp'.")
ipsAuthCredSrpAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 8, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"), (0, "IPS-AUTH-MIB", "ipsAuthCredIndex"))
if mibBuilder.loadTexts: ipsAuthCredSrpAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to a credential that uses\n        ipsAuthMethodSrp as their ipsAuthCredAuthMethod.\n\n\n\n\n        When a row is created in ipsAuthCredentialAttributesTable\n        with ipsAuthCredAuthMethod = ipsAuthCredSrp, the\n        management station must create a corresponding row\n        in this table.\n\n        When a row is deleted from ipsAuthCredentialAttributesTable\n        with ipsAuthCredAuthMethod = ipsAuthCredSrp, the\n        agent must delete the corresponding row (if any) in\n        this table.')
ipsAuthCredSrpUserName = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 8, 1, 1, 1), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredSrpUserName.setDescription('A character string containing the SRP user name for this\n        credential.')
ipsAuthCredSrpRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 8, 1, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredSrpRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The value of\n        ipsAuthCredSrpUserName may be changed while the status\n        of this row is 'active'.")
ipsAuthCredSrpStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 8, 1, 1, 3), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredSrpStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthCredKerberos = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 1, 9))
ipsAuthCredKerbAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 141, 1, 9, 1), )
if mibBuilder.loadTexts: ipsAuthCredKerbAttributesTable.setDescription("A list of Kerberos attributes for credentials that\n        use ipsAuthMethodKerberos as their ipsAuthCredAuthMethod.\n\n        A row in this table can only exist when an instance of\n        the ipsAuthCredAuthMethod object exists (or is created\n        simultaneously) having the same instance identifiers\n        and a value of 'ipsAuthMethodKerb'.")
ipsAuthCredKerbAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 141, 1, 9, 1, 1), ).setIndexNames((0, "IPS-AUTH-MIB", "ipsAuthInstIndex"), (0, "IPS-AUTH-MIB", "ipsAuthIdentIndex"), (0, "IPS-AUTH-MIB", "ipsAuthCredIndex"))
if mibBuilder.loadTexts: ipsAuthCredKerbAttributesEntry.setDescription('An entry (row) containing management information\n        applicable to a credential that uses\n        ipsAuthMethodKerberos as its ipsAuthCredAuthMethod.\n\n        When a row is created in ipsAuthCredentialAttributesTable\n        with ipsAuthCredAuthMethod = ipsAuthCredKerberos, the\n        management station must create a corresponding row\n        in this table.\n\n        When a row is deleted from ipsAuthCredentialAttributesTable\n        with ipsAuthCredAuthMethod = ipsAuthCredKerberos, the\n        agent must delete the corresponding row (if any) in\n        this table.')
ipsAuthCredKerbPrincipal = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 9, 1, 1, 1), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredKerbPrincipal.setDescription('A character string containing a Kerberos principal\n        for this credential.')
ipsAuthCredKerbRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 9, 1, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredKerbRowStatus.setDescription("This field allows entries to be dynamically added and\n        removed from this table via SNMP.  When adding a row to\n        this table, all non-Index/RowStatus objects must be set.\n        Rows may be discarded using RowStatus.  The value of\n        ipsAuthCredKerbPrincipal may be changed while this row\n        is 'active'.")
ipsAuthCredKerbStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 141, 1, 9, 1, 1, 3), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipsAuthCredKerbStorageType.setDescription("The storage type for all read-create objects in this row.\n         Rows in this table that were created through an external\n         process may have a storage type of readOnly or permanent.\n         Conceptual rows having the value 'permanent' need not\n         allow write access to any columnar objects in the row.")
ipsAuthCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 2, 1))
ipsAuthGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 141, 2, 2))
ipsAuthInstanceAttributesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 1)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthInstDescr"), ("IPS-AUTH-MIB", "ipsAuthInstStorageType"),))
if mibBuilder.loadTexts: ipsAuthInstanceAttributesGroup.setDescription('A collection of objects providing information about\n        authorization instances.')
ipsAuthIdentAttributesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 2)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthIdentDescription"), ("IPS-AUTH-MIB", "ipsAuthIdentRowStatus"), ("IPS-AUTH-MIB", "ipsAuthIdentStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentAttributesGroup.setDescription('A collection of objects providing information about\n        user identities within an authorization instance.')
ipsAuthIdentNameAttributesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 3)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthIdentName"), ("IPS-AUTH-MIB", "ipsAuthIdentNameRowStatus"), ("IPS-AUTH-MIB", "ipsAuthIdentNameStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentNameAttributesGroup.setDescription('A collection of objects providing information about\n        user names within user identities within an authorization\n        instance.')
ipsAuthIdentAddrAttributesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 4)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthIdentAddrType"), ("IPS-AUTH-MIB", "ipsAuthIdentAddrStart"), ("IPS-AUTH-MIB", "ipsAuthIdentAddrEnd"), ("IPS-AUTH-MIB", "ipsAuthIdentAddrRowStatus"), ("IPS-AUTH-MIB", "ipsAuthIdentAddrStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentAddrAttributesGroup.setDescription('A collection of objects providing information about\n        address ranges within user identities within an\n        authorization instance.')
ipsAuthIdentCredAttributesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 5)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthCredAuthMethod"), ("IPS-AUTH-MIB", "ipsAuthCredRowStatus"), ("IPS-AUTH-MIB", "ipsAuthCredStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentCredAttributesGroup.setDescription('A collection of objects providing information about\n        credentials within user identities within an authorization\n        instance.')
ipsAuthIdentChapAttrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 6)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthCredChapUserName"), ("IPS-AUTH-MIB", "ipsAuthCredChapRowStatus"), ("IPS-AUTH-MIB", "ipsAuthCredChapStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentChapAttrGroup.setDescription('A collection of objects providing information about\n        CHAP credentials within user identities within an\n        authorization instance.')
ipsAuthIdentSrpAttrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 7)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthCredSrpUserName"), ("IPS-AUTH-MIB", "ipsAuthCredSrpRowStatus"), ("IPS-AUTH-MIB", "ipsAuthCredSrpStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentSrpAttrGroup.setDescription('A collection of objects providing information about\n        SRP credentials within user identities within an\n        authorization instance.')
ipsAuthIdentKerberosAttrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 141, 2, 2, 8)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthCredKerbPrincipal"), ("IPS-AUTH-MIB", "ipsAuthCredKerbRowStatus"), ("IPS-AUTH-MIB", "ipsAuthCredKerbStorageType"),))
if mibBuilder.loadTexts: ipsAuthIdentKerberosAttrGroup.setDescription('A collection of objects providing information about\n        Kerberos credentials within user identities within an\n        authorization instance.')
ipsAuthComplianceV1 = ModuleCompliance((1, 3, 6, 1, 2, 1, 141, 2, 1, 1)).setObjects(*(("IPS-AUTH-MIB", "ipsAuthInstanceAttributesGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentAttributesGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentNameAttributesGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentAddrAttributesGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentCredAttributesGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentChapAttrGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentSrpAttrGroup"), ("IPS-AUTH-MIB", "ipsAuthIdentKerberosAttrGroup"),))
if mibBuilder.loadTexts: ipsAuthComplianceV1.setDescription('Initial version of compliance statement based on\n        initial version of this MIB module.\n\n        The Instance and Identity groups are mandatory;\n        at least one of the other groups (Name, Address,\n        Credential, Certificate) is also mandatory for\n        any given implementation.')
mibBuilder.exportSymbols("IPS-AUTH-MIB", ipsAuthIdentAddrRowStatus=ipsAuthIdentAddrRowStatus, ipsAuthIdentAddrAttributesEntry=ipsAuthIdentAddrAttributesEntry, ipsAuthCompliances=ipsAuthCompliances, ipsAuthMibModule=ipsAuthMibModule, ipsAuthCredKerbPrincipal=ipsAuthCredKerbPrincipal, ipsAuthCredSrpRowStatus=ipsAuthCredSrpRowStatus, ipsAuthCredSrp=ipsAuthCredSrp, ipsAuthMethodKerberos=ipsAuthMethodKerberos, ipsAuthIdentNameAttributesGroup=ipsAuthIdentNameAttributesGroup, ipsAuthIdentIndex=ipsAuthIdentIndex, ipsAuthInstDescr=ipsAuthInstDescr, ipsAuthCredChapAttributesTable=ipsAuthCredChapAttributesTable, ipsAuthIdentStorageType=ipsAuthIdentStorageType, ipsAuthIdentSrpAttrGroup=ipsAuthIdentSrpAttrGroup, ipsAuthCredSrpAttributesEntry=ipsAuthCredSrpAttributesEntry, ipsAuthIdentNameAttributesEntry=ipsAuthIdentNameAttributesEntry, ipsAuthIdentAddrStart=ipsAuthIdentAddrStart, ipsAuthNotifications=ipsAuthNotifications, ipsAuthIdentNameIndex=ipsAuthIdentNameIndex, ipsAuthIdentityName=ipsAuthIdentityName, ipsAuthIdentAttributesEntry=ipsAuthIdentAttributesEntry, ipsAuthIdentAddrIndex=ipsAuthIdentAddrIndex, ipsAuthCredSrpStorageType=ipsAuthCredSrpStorageType, ipsAuthIdentAttributesTable=ipsAuthIdentAttributesTable, ipsAuthIdentNameRowStatus=ipsAuthIdentNameRowStatus, ipsAuthCredIndex=ipsAuthCredIndex, ipsAuthCredKerbAttributesEntry=ipsAuthCredKerbAttributesEntry, ipsAuthIdentAddrType=ipsAuthIdentAddrType, ipsAuthCredKerbRowStatus=ipsAuthCredKerbRowStatus, ipsAuthInstIndex=ipsAuthInstIndex, ipsAuthDescriptors=ipsAuthDescriptors, ipsAuthIdentKerberosAttrGroup=ipsAuthIdentKerberosAttrGroup, ipsAuthCredKerberos=ipsAuthCredKerberos, ipsAuthConformance=ipsAuthConformance, ipsAuthInstanceAttributesEntry=ipsAuthInstanceAttributesEntry, ipsAuthMethodTypes=ipsAuthMethodTypes, ipsAuthIdentChapAttrGroup=ipsAuthIdentChapAttrGroup, ipsAuthInstStorageType=ipsAuthInstStorageType, ipsAuthCredChap=ipsAuthCredChap, ipsAuthIdentAddrAttributesGroup=ipsAuthIdentAddrAttributesGroup, ipsAuthInstance=ipsAuthInstance, ipsAuthIdentNameStorageType=ipsAuthIdentNameStorageType, ipsAuthIdentRowStatus=ipsAuthIdentRowStatus, ipsAuthIdentityAddress=ipsAuthIdentityAddress, ipsAuthIdentDescription=ipsAuthIdentDescription, ipsAuthCredential=ipsAuthCredential, ipsAuthComplianceV1=ipsAuthComplianceV1, ipsAuthCredentialAttributesEntry=ipsAuthCredentialAttributesEntry, ipsAuthGroups=ipsAuthGroups, ipsAuthCredKerbAttributesTable=ipsAuthCredKerbAttributesTable, ipsAuthCredSrpAttributesTable=ipsAuthCredSrpAttributesTable, ipsAuthCredChapUserName=ipsAuthCredChapUserName, ipsAuthIdentName=ipsAuthIdentName, ipsAuthIdentCredAttributesGroup=ipsAuthIdentCredAttributesGroup, ipsAuthIdentity=ipsAuthIdentity, IpsAuthAddress=IpsAuthAddress, ipsAuthObjects=ipsAuthObjects, ipsAuthIdentAddrAttributesTable=ipsAuthIdentAddrAttributesTable, ipsAuthIdentAddrStorageType=ipsAuthIdentAddrStorageType, ipsAuthCredRowStatus=ipsAuthCredRowStatus, ipsAuthCredChapRowStatus=ipsAuthCredChapRowStatus, ipsAuthMethodNone=ipsAuthMethodNone, ipsAuthCredChapStorageType=ipsAuthCredChapStorageType, ipsAuthCredSrpUserName=ipsAuthCredSrpUserName, ipsAuthInstanceAttributesGroup=ipsAuthInstanceAttributesGroup, ipsAuthIdentAddrEnd=ipsAuthIdentAddrEnd, ipsAuthCredAuthMethod=ipsAuthCredAuthMethod, ipsAuthCredStorageType=ipsAuthCredStorageType, ipsAuthCredentialAttributesTable=ipsAuthCredentialAttributesTable, ipsAuthCredChapAttributesEntry=ipsAuthCredChapAttributesEntry, ipsAuthMethodSrp=ipsAuthMethodSrp, ipsAuthIdentNameAttributesTable=ipsAuthIdentNameAttributesTable, ipsAuthCredKerbStorageType=ipsAuthCredKerbStorageType, ipsAuthInstanceAttributesTable=ipsAuthInstanceAttributesTable, ipsAuthMethodChap=ipsAuthMethodChap, PYSNMP_MODULE_ID=ipsAuthMibModule, ipsAuthIdentAttributesGroup=ipsAuthIdentAttributesGroup)
